Class: Google::Cloud::NetworkSecurity::V1::AddAddressGroupItemsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/address_group.rb

Overview

Request used by the AddAddressGroupItems method.

Instance Attribute Summary collapse

Instance Attribute Details

#address_group::String

Returns Required. A name of the AddressGroup to add items to. Must be in the format projects|organization/*/locations/{location}/addressGroups/*.

Returns:

  • (::String)

    Required. A name of the AddressGroup to add items to. Must be in the format projects|organization/*/locations/{location}/addressGroups/*.



261
262
263
264
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 261

class AddAddressGroupItemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items::Array<::String>

Returns Required. List of items to add.

Returns:

  • (::Array<::String>)

    Required. List of items to add.



261
262
263
264
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 261

class AddAddressGroupItemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



261
262
263
264
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 261

class AddAddressGroupItemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end