Module: Google::Cloud::NetworkSecurity::V1::AddressGroupService

Defined in:
lib/google/cloud/network_security/v1/address_group_service.rb,
lib/google/cloud/network_security/v1/address_group_service/paths.rb,
lib/google/cloud/network_security/v1/address_group_service/client.rb,
lib/google/cloud/network_security/v1/address_group_service/operations.rb,
lib/google/cloud/network_security/v1/address_group_service/credentials.rb

Overview

AddressGroup is a resource that manages a collection of IP or Domain Names, it can be used in Firewall Policy to represent allow or deny traffic from all the IP or Domain Names from the Address Group.

Examples:

Load this service and instantiate a gRPC client


require "google/cloud/network_security/v1/address_group_service"
client = ::Google::Cloud::NetworkSecurity::V1::AddressGroupService::Client.new

Defined Under Namespace

Modules: Paths Classes: Client, Credentials, Operations