Class: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::AuthzRule::HeaderMatch

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/authz_policy.rb

Overview

Determines how a HTTP header should be matched.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Optional. Specifies the name of the header in the request.

Returns:

  • (::String)

    Optional. Specifies the name of the header in the request.



241
242
243
244
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 241

class HeaderMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::AuthzRule::StringMatch

Returns Optional. Specifies how the header match will be performed.

Returns:



241
242
243
244
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 241

class HeaderMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end