Class: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::AuthzRule::RequestResource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/authz_policy.rb

Overview

Describes the properties of a client VM resource accessing the internal application load balancers.

Defined Under Namespace

Classes: TagValueIdSet

Instance Attribute Summary collapse

Instance Attribute Details

#iam_service_account::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::AuthzRule::StringMatch

Returns Optional. An IAM service account to match against the source service account of the VM sending the request.

Returns:



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 215

class RequestResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a set of resource tag value permanent IDs to match against
  # the resource manager tags value associated with the source VM of a
  # request.
  # @!attribute [rw] ids
  #   @return [::Array<::Integer>]
  #     Required. A list of resource tag value permanent IDs to match against
  #     the resource manager tags value associated with the source VM of a
  #     request. The match follows AND semantics which means all
  #     the ids must match. Limited to 5 ids in the Tag value id set.
  class TagValueIdSet
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tag_value_id_set::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::AuthzRule::RequestResource::TagValueIdSet

Returns Optional. A list of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request.

Returns:



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 215

class RequestResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a set of resource tag value permanent IDs to match against
  # the resource manager tags value associated with the source VM of a
  # request.
  # @!attribute [rw] ids
  #   @return [::Array<::Integer>]
  #     Required. A list of resource tag value permanent IDs to match against
  #     the resource manager tags value associated with the source VM of a
  #     request. The match follows AND semantics which means all
  #     the ids must match. Limited to 5 ids in the Tag value id set.
  class TagValueIdSet
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end