Class: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::AuthzRule::StringMatch

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/authz_policy.rb

Overview

Determines how a string value should be matched.

Instance Attribute Summary collapse

Instance Attribute Details

#contains::String

Returns The input string must have the substring specified here. Note: empty contains match is not allowed, please use regex instead.

Examples:

  • abc matches the value xyz.abc.def

Note: The following fields are mutually exclusive: contains, exact, prefix, suffix. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The input string must have the substring specified here. Note: empty contains match is not allowed, please use regex instead.

    Examples:

    • abc matches the value xyz.abc.def

    Note: The following fields are mutually exclusive: contains, exact, prefix, suffix. If a field in that set is populated, all other fields in the set will automatically be cleared.



187
188
189
190
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 187

class StringMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#exact::String

Returns The input string must match exactly the string specified here.

Examples:

  • abc only matches the value abc.

Note: The following fields are mutually exclusive: exact, prefix, suffix, contains. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The input string must match exactly the string specified here.

    Examples:

    • abc only matches the value abc.

    Note: The following fields are mutually exclusive: exact, prefix, suffix, contains. If a field in that set is populated, all other fields in the set will automatically be cleared.



187
188
189
190
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 187

class StringMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ignore_case::Boolean

Returns If true, indicates the exact/prefix/suffix/contains matching should be case insensitive. For example, the matcher data will match both input string Data and data if set to true.

Returns:

  • (::Boolean)

    If true, indicates the exact/prefix/suffix/contains matching should be case insensitive. For example, the matcher data will match both input string Data and data if set to true.



187
188
189
190
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 187

class StringMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#prefix::String

Returns The input string must have the prefix specified here. Note: empty prefix is not allowed, please use regex instead.

Examples:

  • abc matches the value abc.xyz

Note: The following fields are mutually exclusive: prefix, exact, suffix, contains. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The input string must have the prefix specified here. Note: empty prefix is not allowed, please use regex instead.

    Examples:

    • abc matches the value abc.xyz

    Note: The following fields are mutually exclusive: prefix, exact, suffix, contains. If a field in that set is populated, all other fields in the set will automatically be cleared.



187
188
189
190
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 187

class StringMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#suffix::String

Returns The input string must have the suffix specified here. Note: empty prefix is not allowed, please use regex instead.

Examples:

  • abc matches the value xyz.abc

Note: The following fields are mutually exclusive: suffix, exact, prefix, contains. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The input string must have the suffix specified here. Note: empty prefix is not allowed, please use regex instead.

    Examples:

    • abc matches the value xyz.abc

    Note: The following fields are mutually exclusive: suffix, exact, prefix, contains. If a field in that set is populated, all other fields in the set will automatically be cleared.



187
188
189
190
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 187

class StringMatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end