Class: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider::AuthzExtension

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/authz_policy.rb

Overview

Optional. Delegate authorization decision to user authored extension. Only one of cloudIap or authzExtension can be specified.

Instance Attribute Summary collapse

Instance Attribute Details

#resources::Array<::String>

Returns Required. A list of references to authorization extensions that will be invoked for requests matching this policy. Limited to 1 custom provider.

Returns:

  • (::Array<::String>)

    Required. A list of references to authorization extensions that will be invoked for requests matching this policy. Limited to 1 custom provider.



521
522
523
524
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 521

class AuthzExtension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end