Module: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::LoadBalancingScheme

Defined in:
proto_docs/google/cloud/networksecurity/v1/authz_policy.rb

Overview

Load balancing schemes supported by the AuthzPolicy resource. The valid values are INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer to Backend services overview.

Constant Summary collapse

LOAD_BALANCING_SCHEME_UNSPECIFIED =

Default value. Do not use.

0
INTERNAL_MANAGED =

Signifies that this is used for Regional internal or Cross-region internal Application Load Balancing.

1
EXTERNAL_MANAGED =

Signifies that this is used for Global external or Regional external Application Load Balancing.

2
INTERNAL_SELF_MANAGED =

Signifies that this is used for Cloud Service Mesh. Meant for use by CSM GKE controller only.

3