Module: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::PolicyProfile

Defined in:
proto_docs/google/cloud/networksecurity/v1/authz_policy.rb

Overview

The type of authorization being performed. New values may be added in the future.

Constant Summary collapse

POLICY_PROFILE_UNSPECIFIED =

Unspecified policy profile.

0
REQUEST_AUTHZ =

Applies to request authorization. CUSTOM authorization policies with Authz extensions will be allowed with EXT_AUTHZ_GRPC or EXT_PROC_GRPC protocols. Extensions are invoked only for request header events.

1
CONTENT_AUTHZ =

Applies to content security, sanitization, etc. Only CUSTOM action is allowed in this policy profile. AuthzExtensions in the custom provider must support EXT_PROC_GRPC protocol only and be capable of receiving all EXT_PROC_GRPC events (REQUEST_HEADERS, REQUEST_BODY, REQUEST_TRAILERS, RESPONSE_HEADERS, RESPONSE_BODY, RESPONSE_TRAILERS) with FULL_DUPLEX_STREAMED body send mode.

2