Class: Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb

Overview

BackendAuthenticationConfig message groups the TrustConfig together with other settings that control how the load balancer authenticates, and expresses its identity to, the backend:

  • trustConfig is the attached TrustConfig.

  • wellKnownRoots indicates whether the load balance should trust backend server certificates that are issued by public certificate authorities, in addition to certificates trusted by the TrustConfig.

  • clientCertificate is a client certificate that the load balancer uses to express its identity to the backend, if the connection to the backend uses mTLS.

You can attach the BackendAuthenticationConfig to the load balancer's BackendService directly determining how that BackendService negotiates TLS.

Defined Under Namespace

Modules: WellKnownRoots Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#client_certificate::String

Returns Optional. A reference to a certificatemanager.googleapis.com.Certificate resource. This is a relative resource path following the form "projects/{project}/locations/{location}/certificates/{certificate}".

Used by a BackendService to negotiate mTLS when the backend connection uses TLS and the backend requests a client certificate. Must have a CLIENT_AUTH scope.

Returns:

  • (::String)

    Optional. A reference to a certificatemanager.googleapis.com.Certificate resource. This is a relative resource path following the form "projects/{project}/locations/{location}/certificates/{certificate}".

    Used by a BackendService to negotiate mTLS when the backend connection uses TLS and the backend requests a client certificate. Must have a CLIENT_AUTH scope.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created.

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#description::String

Returns Optional. Free-text description of the resource.

Returns:

  • (::String)

    Optional. Free-text description of the resource.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#etag::String (readonly)

Returns Output only. Etag of the resource.

Returns:

  • (::String)

    Output only. Etag of the resource.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Set of label tags associated with the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Set of label tags associated with the resource.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#name::String

Returns Required. Name of the BackendAuthenticationConfig resource. It matches the pattern projects/*/locations/{location}/backendAuthenticationConfigs/{backend_authentication_config}.

Returns:

  • (::String)

    Required. Name of the BackendAuthenticationConfig resource. It matches the pattern projects/*/locations/{location}/backendAuthenticationConfigs/{backend_authentication_config}



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#trust_config::String

Returns Optional. A reference to a TrustConfig resource from the certificatemanager.googleapis.com namespace. This is a relative resource path following the form "projects/{project}/locations/{location}/trustConfigs/{trust_config}".

A BackendService uses the chain of trust represented by this TrustConfig, if specified, to validate the server certificates presented by the backend. Required unless wellKnownRoots is set to PUBLIC_ROOTS.

Returns:

  • (::String)

    Optional. A reference to a TrustConfig resource from the certificatemanager.googleapis.com namespace. This is a relative resource path following the form "projects/{project}/locations/{location}/trustConfigs/{trust_config}".

    A BackendService uses the chain of trust represented by this TrustConfig, if specified, to validate the server certificates presented by the backend. Required unless wellKnownRoots is set to PUBLIC_ROOTS.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was updated.

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end

#well_known_roots::Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig::WellKnownRoots

Returns Well known roots to use for server certificate validation.

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 82

class BackendAuthenticationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum to specify the well known roots to use for server certificate
  # validation.
  module WellKnownRoots
    # Equivalent to NONE.
    WELL_KNOWN_ROOTS_UNSPECIFIED = 0

    # The BackendService will only validate server certificates against roots
    # specified in TrustConfig.
    NONE = 1

    # The BackendService uses a set of well-known public roots, in addition to
    # any roots specified in the trustConfig field, when validating the server
    # certificates presented by the backend. Validation with these roots is
    # only considered when the TlsSettings.sni field in the BackendService is
    # set.
    #
    # The well-known roots are a set of root CAs managed by Google. CAs in this
    # set can be added or removed without notice.
    PUBLIC_ROOTS = 2
  end
end