Module: Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig::WellKnownRoots

Defined in:
proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb

Overview

Enum to specify the well known roots to use for server certificate validation.

Constant Summary collapse

WELL_KNOWN_ROOTS_UNSPECIFIED =

Equivalent to NONE.

0
NONE =

The BackendService will only validate server certificates against roots specified in TrustConfig.

1
PUBLIC_ROOTS =

The BackendService uses a set of well-known public roots, in addition to any roots specified in the trustConfig field, when validating the server certificates presented by the backend. Validation with these roots is only considered when the TlsSettings.sni field in the BackendService is set.

The well-known roots are a set of root CAs managed by Google. CAs in this set can be added or removed without notice.

2