Class: Google::Cloud::NetworkSecurity::V1::CreateBackendAuthenticationConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb

Overview

Request used by the CreateBackendAuthenticationConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#backend_authentication_config::Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig

Returns Required. BackendAuthenticationConfig resource to be created.

Returns:



178
179
180
181
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 178

class CreateBackendAuthenticationConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backend_authentication_config_id::String

Returns Required. Short name of the BackendAuthenticationConfig resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "backend-auth-config".

Returns:

  • (::String)

    Required. Short name of the BackendAuthenticationConfig resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "backend-auth-config".



178
179
180
181
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 178

class CreateBackendAuthenticationConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the BackendAuthenticationConfig. Must be in the format projects/*/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource of the BackendAuthenticationConfig. Must be in the format projects/*/locations/{location}.



178
179
180
181
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 178

class CreateBackendAuthenticationConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end