Class: Google::Cloud::NetworkSecurity::V1::CreateFirewallEndpointAssociationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateFirewallEndpointAssociationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb
Overview
Message for creating a Association
Instance Attribute Summary collapse
-
#firewall_endpoint_association ⇒ ::Google::Cloud::NetworkSecurity::V1::FirewallEndpointAssociation
Required.
-
#firewall_endpoint_association_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#firewall_endpoint_association ⇒ ::Google::Cloud::NetworkSecurity::V1::FirewallEndpointAssociation
Returns Required. The resource being created.
407 408 409 410 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 407 class CreateFirewallEndpointAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#firewall_endpoint_association_id ⇒ ::String
Returns Optional. Id of the requesting object. If auto-generating Id server-side, remove this field and firewall_endpoint_association_id from the method_signature of Create RPC.
407 408 409 410 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 407 class CreateFirewallEndpointAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Value for parent.
407 408 409 410 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 407 class CreateFirewallEndpointAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
407 408 409 410 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 407 class CreateFirewallEndpointAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |