Class: Google::Cloud::NetworkSecurity::V1::CreateGatewaySecurityPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/gateway_security_policy.rb

Overview

Request used by the CreateGatewaySecurityPolicy method.

Instance Attribute Summary collapse

Instance Attribute Details

#gateway_security_policy::Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicy

Returns Required. GatewaySecurityPolicy resource to be created.

Returns:



64
65
66
67
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy.rb', line 64

class CreateGatewaySecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gateway_security_policy_id::String

Returns Required. Short name of the GatewaySecurityPolicy resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "gateway_security_policy1".

Returns:

  • (::String)

    Required. Short name of the GatewaySecurityPolicy resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "gateway_security_policy1".



64
65
66
67
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy.rb', line 64

class CreateGatewaySecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the GatewaySecurityPolicy. Must be in the format projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource of the GatewaySecurityPolicy. Must be in the format projects/{project}/locations/{location}.



64
65
66
67
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy.rb', line 64

class CreateGatewaySecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end