Class: Google::Cloud::NetworkSecurity::V1::CreateInterceptDeploymentGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

Request message for CreateInterceptDeploymentGroup.

Instance Attribute Summary collapse

Instance Attribute Details

#intercept_deployment_group::Google::Cloud::NetworkSecurity::V1::InterceptDeploymentGroup

Returns Required. The deployment group to create.

Returns:



689
690
691
692
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 689

class CreateInterceptDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#intercept_deployment_group_id::String

Returns Required. The ID to use for the new deployment group, which will become the final component of the deployment group's resource name.

Returns:

  • (::String)

    Required. The ID to use for the new deployment group, which will become the final component of the deployment group's resource name.



689
690
691
692
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 689

class CreateInterceptDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this deployment group will be created. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource where this deployment group will be created. Format: projects/{project}/locations/{location}



689
690
691
692
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 689

class CreateInterceptDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. Must be a UUID4. This request is only idempotent if a request_id is provided. See https://google.aip.dev/155 for more details.

Returns:

  • (::String)

    Optional. A unique identifier for this request. Must be a UUID4. This request is only idempotent if a request_id is provided. See https://google.aip.dev/155 for more details.



689
690
691
692
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 689

class CreateInterceptDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end