Class: Google::Cloud::NetworkSecurity::V1::CreateInterceptDeploymentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateInterceptDeploymentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
Request message for CreateInterceptDeployment.
Instance Attribute Summary collapse
-
#intercept_deployment ⇒ ::Google::Cloud::NetworkSecurity::V1::InterceptDeployment
Required.
-
#intercept_deployment_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#intercept_deployment ⇒ ::Google::Cloud::NetworkSecurity::V1::InterceptDeployment
Returns Required. The deployment to create.
892 893 894 895 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 892 class CreateInterceptDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#intercept_deployment_id ⇒ ::String
Returns Required. The ID to use for the new deployment, which will become the final component of the deployment's resource name.
892 893 894 895 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 892 class CreateInterceptDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this deployment will be created. Format: projects/{project}/locations/{location}.
892 893 894 895 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 892 class CreateInterceptDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
892 893 894 895 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 892 class CreateInterceptDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |