Class: Google::Cloud::NetworkSecurity::V1::CreateInterceptEndpointGroupAssociationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

Request message for CreateInterceptEndpointGroupAssociation.

Instance Attribute Summary collapse

Instance Attribute Details

#intercept_endpoint_group_association::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation

Returns Required. The association to create.

Returns:



472
473
474
475
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 472

class CreateInterceptEndpointGroupAssociationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#intercept_endpoint_group_association_id::String

Returns Optional. The ID to use for the new association, which will become the final component of the endpoint group's resource name. If not provided, the server will generate a unique ID.

Returns:

  • (::String)

    Optional. The ID to use for the new association, which will become the final component of the endpoint group's resource name. If not provided, the server will generate a unique ID.



472
473
474
475
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 472

class CreateInterceptEndpointGroupAssociationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this association will be created. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource where this association will be created. Format: projects/{project}/locations/{location}



472
473
474
475
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 472

class CreateInterceptEndpointGroupAssociationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. Must be a UUID4. This request is only idempotent if a request_id is provided. See https://google.aip.dev/155 for more details.

Returns:

  • (::String)

    Optional. A unique identifier for this request. Must be a UUID4. This request is only idempotent if a request_id is provided. See https://google.aip.dev/155 for more details.



472
473
474
475
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 472

class CreateInterceptEndpointGroupAssociationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end