Class: Google::Cloud::NetworkSecurity::V1::CreateInterceptEndpointGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

Request message for CreateInterceptEndpointGroup.

Instance Attribute Summary collapse

Instance Attribute Details

#intercept_endpoint_group::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroup

Returns Required. The endpoint group to create.

Returns:



227
228
229
230
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 227

class CreateInterceptEndpointGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#intercept_endpoint_group_id::String

Returns Required. The ID to use for the endpoint group, which will become the final component of the endpoint group's resource name.

Returns:

  • (::String)

    Required. The ID to use for the endpoint group, which will become the final component of the endpoint group's resource name.



227
228
229
230
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 227

class CreateInterceptEndpointGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this endpoint group will be created. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource where this endpoint group will be created. Format: projects/{project}/locations/{location}



227
228
229
230
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 227

class CreateInterceptEndpointGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. Must be a UUID4. This request is only idempotent if a request_id is provided. See https://google.aip.dev/155 for more details.

Returns:

  • (::String)

    Optional. A unique identifier for this request. Must be a UUID4. This request is only idempotent if a request_id is provided. See https://google.aip.dev/155 for more details.



227
228
229
230
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 227

class CreateInterceptEndpointGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end