Class: Google::Cloud::NetworkSecurity::V1::CreateMirroringDeploymentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateMirroringDeploymentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/mirroring.rb
Overview
Request message for CreateMirroringDeployment.
Instance Attribute Summary collapse
-
#mirroring_deployment ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeployment
Required.
-
#mirroring_deployment_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#mirroring_deployment ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeployment
Returns Required. The deployment to create.
902 903 904 905 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 902 class CreateMirroringDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mirroring_deployment_id ⇒ ::String
Returns Required. The ID to use for the new deployment, which will become the final component of the deployment's resource name.
902 903 904 905 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 902 class CreateMirroringDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this deployment will be created. Format: projects/{project}/locations/{location}.
902 903 904 905 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 902 class CreateMirroringDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
902 903 904 905 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 902 class CreateMirroringDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |