Class: Google::Cloud::NetworkSecurity::V1::CreateMirroringEndpointGroupAssociationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateMirroringEndpointGroupAssociationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/mirroring.rb
Overview
Request message for CreateMirroringEndpointGroupAssociation.
Instance Attribute Summary collapse
-
#mirroring_endpoint_group_association ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation
Required.
-
#mirroring_endpoint_group_association_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#mirroring_endpoint_group_association ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation
Returns Required. The association to create.
479 480 481 482 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 479 class CreateMirroringEndpointGroupAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mirroring_endpoint_group_association_id ⇒ ::String
Returns Optional. The ID to use for the new association, which will become the final component of the endpoint group's resource name. If not provided, the server will generate a unique ID.
479 480 481 482 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 479 class CreateMirroringEndpointGroupAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this association will be created. Format: projects/{project}/locations/{location}.
479 480 481 482 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 479 class CreateMirroringEndpointGroupAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
479 480 481 482 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 479 class CreateMirroringEndpointGroupAssociationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |