Class: Google::Cloud::NetworkSecurity::V1::CreateSACAttachmentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/sse_realm.rb

Overview

Request for CreateSACAttachment method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent, in the form projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent, in the form projects/{project}/locations/{location}.



356
357
358
359
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 356

class CreateSACAttachmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



356
357
358
359
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 356

class CreateSACAttachmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sac_attachment::Google::Cloud::NetworkSecurity::V1::SACAttachment

Returns Required. The resource being created.

Returns:



356
357
358
359
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 356

class CreateSACAttachmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sac_attachment_id::String

Returns Required. ID of the created attachment. The ID must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Required. ID of the created attachment. The ID must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



356
357
358
359
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 356

class CreateSACAttachmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end