Class: Google::Cloud::NetworkSecurity::V1::CreateSecurityProfileGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb

Overview

Request used by the CreateSecurityProfileGroup method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource of the SecurityProfileGroup. Must be in the format projects|organizations/*/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource of the SecurityProfileGroup. Must be in the format projects|organizations/*/locations/{location}.



82
83
84
85
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 82

class CreateSecurityProfileGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_profile_group::Google::Cloud::NetworkSecurity::V1::SecurityProfileGroup

Returns Required. SecurityProfileGroup resource to be created.

Returns:



82
83
84
85
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 82

class CreateSecurityProfileGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_profile_group_id::String

Returns Required. Short name of the SecurityProfileGroup resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "security_profile_group1".

Returns:

  • (::String)

    Required. Short name of the SecurityProfileGroup resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "security_profile_group1".



82
83
84
85
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 82

class CreateSecurityProfileGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end