Class: Google::Cloud::NetworkSecurity::V1::CreateSecurityProfileRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb

Overview

Request used by the CreateSecurityProfile method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource of the SecurityProfile. Must be in the format projects|organizations/*/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource of the SecurityProfile. Must be in the format projects|organizations/*/locations/{location}.



175
176
177
178
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 175

class CreateSecurityProfileRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_profile::Google::Cloud::NetworkSecurity::V1::SecurityProfile

Returns Required. SecurityProfile resource to be created.

Returns:



175
176
177
178
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 175

class CreateSecurityProfileRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_profile_id::String

Returns Required. Short name of the SecurityProfile resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "security_profile1".

Returns:

  • (::String)

    Required. Short name of the SecurityProfile resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "security_profile1".



175
176
177
178
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 175

class CreateSecurityProfileRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end