Class: Google::Cloud::NetworkSecurity::V1::CreateTlsInspectionPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb

Overview

Request used by the CreateTlsInspectionPolicy method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource of the TlsInspectionPolicy. Must be in the format projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource of the TlsInspectionPolicy. Must be in the format projects/{project}/locations/{location}.



153
154
155
156
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 153

class CreateTlsInspectionPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tls_inspection_policy::Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy

Returns Required. TlsInspectionPolicy resource to be created.

Returns:



153
154
155
156
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 153

class CreateTlsInspectionPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tls_inspection_policy_id::String

Returns Required. Short name of the TlsInspectionPolicy resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "tls_inspection_policy1".

Returns:

  • (::String)

    Required. Short name of the TlsInspectionPolicy resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "tls_inspection_policy1".



153
154
155
156
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 153

class CreateTlsInspectionPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end