Class: Google::Cloud::NetworkSecurity::V1::CustomInterceptProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/security_profile_group_intercept.rb

Overview

CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.

Instance Attribute Summary collapse

Instance Attribute Details

#intercept_endpoint_group::String

Returns Required. The target InterceptEndpointGroup. When a firewall rule with this security profile attached matches a packet, the packet will be intercepted to the location-local target in this group.

Returns:

  • (::String)

    Required. The target InterceptEndpointGroup. When a firewall rule with this security profile attached matches a packet, the packet will be intercepted to the location-local target in this group.



31
32
33
34
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_intercept.rb', line 31

class CustomInterceptProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end