Class: Google::Cloud::NetworkSecurity::V1::CustomMirroringProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/security_profile_group_mirroring.rb

Overview

CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.

Instance Attribute Summary collapse

Instance Attribute Details

#mirroring_endpoint_group::String

Returns Required. Immutable. The target MirroringEndpointGroup. When a mirroring rule with this security profile attached matches a packet, a replica will be mirrored to the location-local target in this group.

Returns:

  • (::String)

    Required. Immutable. The target MirroringEndpointGroup. When a mirroring rule with this security profile attached matches a packet, a replica will be mirrored to the location-local target in this group.



31
32
33
34
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_mirroring.rb', line 31

class CustomMirroringProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end