Class: Google::Cloud::NetworkSecurity::V1::DeleteSecurityProfileRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb

Overview

Request used by the DeleteSecurityProfile method.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. If client provided etag is out of date, delete will return FAILED_PRECONDITION error.

Returns:

  • (::String)

    Optional. If client provided etag is out of date, delete will return FAILED_PRECONDITION error.



204
205
206
207
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 204

class DeleteSecurityProfileRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. A name of the SecurityProfile to delete. Must be in the format projects|organizations/*/locations/{location}/securityProfiles/{security_profile_id}.

Returns:

  • (::String)

    Required. A name of the SecurityProfile to delete. Must be in the format projects|organizations/*/locations/{location}/securityProfiles/{security_profile_id}.



204
205
206
207
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 204

class DeleteSecurityProfileRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end