Class: Google::Cloud::NetworkSecurity::V1::DeleteTlsInspectionPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb

Overview

Request used by the DeleteTlsInspectionPolicy method.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns If set to true, any rules for this TlsInspectionPolicy will also be deleted. (Otherwise, the request will only work if the TlsInspectionPolicy has no rules.).

Returns:

  • (::Boolean)

    If set to true, any rules for this TlsInspectionPolicy will also be deleted. (Otherwise, the request will only work if the TlsInspectionPolicy has no rules.)



216
217
218
219
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 216

class DeleteTlsInspectionPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. A name of the TlsInspectionPolicy to delete. Must be in the format projects/{project}/locations/{location}/tlsInspectionPolicies/{tls_inspection_policy}.

Returns:

  • (::String)

    Required. A name of the TlsInspectionPolicy to delete. Must be in the format projects/{project}/locations/{location}/tlsInspectionPolicies/{tls_inspection_policy}.



216
217
218
219
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 216

class DeleteTlsInspectionPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end