Class: Google::Cloud::NetworkSecurity::V1::FirewallEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb

Overview

Message describing Endpoint object.

Defined Under Namespace

Modules: State Classes: AssociationReference, EndpointSettings, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#associated_networks::Array<::String> (readonly)

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Output only. Deprecated: List of networks that are associated with this endpoint in the local zone. This is a projection of the FirewallEndpointAssociations pointing at this endpoint. A network will only appear in this list after traffic routing is fully configured. Format: projects/{project}/global/networks/{name}.

Returns:

  • (::Array<::String>)

    Output only. Deprecated: List of networks that are associated with this endpoint in the local zone. This is a projection of the FirewallEndpointAssociations pointing at this endpoint. A network will only appear in this list after traffic routing is fully configured. Format: projects/{project}/global/networks/{name}.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#associations::Array<::Google::Cloud::NetworkSecurity::V1::FirewallEndpoint::AssociationReference> (readonly)

Returns Output only. List of FirewallEndpointAssociations that are associated to this endpoint. An association will only appear in this list after traffic routing is fully configured.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#billing_project_id::String

Returns Optional. Project to charge for the deployed firewall endpoint. This field must be specified when creating the endpoint in the organization scope, and should be omitted otherwise.

Returns:

  • (::String)

    Optional. Project to charge for the deployed firewall endpoint. This field must be specified when creating the endpoint in the organization scope, and should be omitted otherwise.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create time stamp.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#description::String

Returns Optional. Description of the firewall endpoint. Max length 2048 characters.

Returns:

  • (::String)

    Optional. Description of the firewall endpoint. Max length 2048 characters.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#endpoint_settings::Google::Cloud::NetworkSecurity::V1::FirewallEndpoint::EndpointSettings

Returns Optional. Settings for the endpoint.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels as key value pairs.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels as key value pairs



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#name::String

Returns Immutable. Identifier. Name of resource.

Returns:

  • (::String)

    Immutable. Identifier. Name of resource.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#reconciling::Boolean (readonly)

Returns Output only. Whether reconciling is in progress, recommended per https://google.aip.dev/128.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#satisfies_pzi::Boolean (readonly)

Returns Output only. [Output Only] Reserved for future use.

Returns:

  • (::Boolean)

    Output only. [Output Only] Reserved for future use.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#satisfies_pzs::Boolean (readonly)

Returns Output only. [Output Only] Reserved for future use.

Returns:

  • (::Boolean)

    Output only. [Output Only] Reserved for future use.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#state::Google::Cloud::NetworkSecurity::V1::FirewallEndpoint::State (readonly)

Returns Output only. Current state of the endpoint.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update time stamp.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 75

class FirewallEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This is a subset of the FirewallEndpointAssociation message, containing
  # fields to be used by the consumer.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the FirewallEndpointAssociation.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/firewallEndpointAssociations/\\{id}
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The VPC network associated. Format:
  #     projects/\\{project}/global/networks/\\{name}.
  class AssociationReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Settings for the endpoint.
  # @!attribute [rw] jumbo_frames_enabled
  #   @return [::Boolean]
  #     Optional. Immutable. Indicates whether Jumbo Frames are enabled.
  #     Default value is false.
  class EndpointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Endpoint state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Processing configuration updates.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4
  end
end