Class: Google::Cloud::NetworkSecurity::V1::FirewallEndpointAssociation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb

Overview

Message describing Association object

Defined Under Namespace

Modules: State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create time stamp.

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#disabled::Boolean

Returns Optional. Whether the association is disabled. True indicates that traffic won't be intercepted.

Returns:

  • (::Boolean)

    Optional. Whether the association is disabled. True indicates that traffic won't be intercepted



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#firewall_endpoint::String

Returns Required. The URL of the FirewallEndpoint that is being associated.

Returns:

  • (::String)

    Required. The URL of the FirewallEndpoint that is being associated.



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels as key value pairs.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels as key value pairs



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#name::String

Returns Immutable. Identifier. name of resource.

Returns:

  • (::String)

    Immutable. Identifier. name of resource



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#network::String

Returns Required. The URL of the network that is being associated.

Returns:

  • (::String)

    Required. The URL of the network that is being associated.



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#reconciling::Boolean (readonly)

Returns Output only. Whether reconciling is in progress, recommended per https://google.aip.dev/128.

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#state::Google::Cloud::NetworkSecurity::V1::FirewallEndpointAssociation::State (readonly)

Returns Output only. Current state of the association.

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#tls_inspection_policy::String

Returns Optional. The URL of the TlsInspectionPolicy that is being associated.

Returns:

  • (::String)

    Optional. The URL of the TlsInspectionPolicy that is being associated.



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update time stamp.

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 299

class FirewallEndpointAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Association state.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # Being created.
    CREATING = 1

    # Active and ready for traffic.
    ACTIVE = 2

    # Being deleted.
    DELETING = 3

    # Down or in an error state.
    INACTIVE = 4

    # The project that housed the association has been deleted.
    ORPHAN = 5
  end
end