Class: Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicyRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb

Overview

The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.

Defined Under Namespace

Modules: BasicProfile

Instance Attribute Summary collapse

Instance Attribute Details

#application_matcher::String

Returns Optional. CEL expression for matching on L7/application level criteria.

Returns:

  • (::String)

    Optional. CEL expression for matching on L7/application level criteria.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#basic_profile::Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicyRule::BasicProfile

Returns Required. Profile which tells what the primitive action should be.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the rule was created.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#description::String

Returns Optional. Free-text description of the resource.

Returns:

  • (::String)

    Optional. Free-text description of the resource.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#enabled::Boolean

Returns Required. Whether the rule is enforced.

Returns:

  • (::Boolean)

    Required. Whether the rule is enforced.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#name::String

Returns Required. Immutable. Name of the resource. ame is the full resource name so projects/{project}/locations/{location}/gatewaySecurityPolicies/{gateway_security_policy}/rules/{rule} rule should match the pattern: (^a-z?$).

Returns:

  • (::String)

    Required. Immutable. Name of the resource. ame is the full resource name so projects/{project}/locations/{location}/gatewaySecurityPolicies/{gateway_security_policy}/rules/{rule} rule should match the pattern: (^a-z?$).



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#priority::Integer

Returns Required. Priority of the rule. Lower number corresponds to higher precedence.

Returns:

  • (::Integer)

    Required. Priority of the rule. Lower number corresponds to higher precedence.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#session_matcher::String

Returns Required. CEL expression for matching on session criteria.

Returns:

  • (::String)

    Required. CEL expression for matching on session criteria.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#tls_inspection_enabled::Boolean

Returns Optional. Flag to enable TLS inspection of traffic matching on , can only be true if the parent GatewaySecurityPolicy references a TLSInspectionConfig.

Returns:

  • (::Boolean)

    Optional. Flag to enable TLS inspection of traffic matching on , can only be true if the parent GatewaySecurityPolicy references a TLSInspectionConfig.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the rule was updated.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 63

class GatewaySecurityPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # enum to define the primitive action.
  module BasicProfile
    # If there is not a mentioned action for the target.
    BASIC_PROFILE_UNSPECIFIED = 0

    # Allow the matched traffic.
    ALLOW = 1

    # Deny the matched traffic.
    DENY = 2
  end
end