Module: Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
The current state of the deployment.
Constant Summary collapse
- STATE_UNSPECIFIED =
State not set (this is not a valid state).
0- ACTIVE =
The deployment is ready and in sync with the parent group.
1- CREATING =
The deployment is being created.
2- DELETING =
The deployment is being deleted.
3- OUT_OF_SYNC =
The deployment is out of sync with the parent group. In most cases, this is a result of a transient issue within the system (e.g. a delayed data-path config) and the system is expected to recover automatically. See the parent deployment group's state for more details.
4- DELETE_FAILED =
An attempt to delete the deployment has failed. This is a terminal state and the deployment is not expected to recover. The only permitted operation is to retry deleting the deployment.
5