Class: Google::Cloud::NetworkSecurity::V1::InterceptDeploymentGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

A deployment group aggregates many zonal intercept backends (deployments) into a single global intercept service. Consumers can connect this service using an endpoint group.

Defined Under Namespace

Modules: State Classes: ConnectedEndpointGroup, Deployment, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#connected_endpoint_groups::Array<::Google::Cloud::NetworkSecurity::V1::InterceptDeploymentGroup::ConnectedEndpointGroup> (readonly)

Returns Output only. The list of endpoint groups that are connected to this resource.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#description::String

Returns Optional. User-provided description of the deployment group. Used as additional context for the deployment group.

Returns:

  • (::String)

    Optional. User-provided description of the deployment group. Used as additional context for the deployment group.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels are key/value pairs that help to organize and filter resources.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels are key/value pairs that help to organize and filter resources.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#locations::Array<::Google::Cloud::NetworkSecurity::V1::InterceptLocation> (readonly)

Returns Output only. The list of locations where the deployment group is present.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#name::String

Returns Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/interceptDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details.

Returns:

  • (::String)

    Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/interceptDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#nested_deployments::Array<::Google::Cloud::NetworkSecurity::V1::InterceptDeploymentGroup::Deployment> (readonly)

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Output only. The list of Intercept Deployments that belong to this group.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#network::String

Returns Required. Immutable. The network that will be used for all child deployments, for example: projects/{project}/global/networks/{network}. See https://google.aip.dev/124.

Returns:

  • (::String)

    Required. Immutable. The network that will be used for all child deployments, for example: projects/{project}/global/networks/{network}. See https://google.aip.dev/124.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#reconciling::Boolean (readonly)

Returns Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https://google.aip.dev/128.

Returns:

  • (::Boolean)

    Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https://google.aip.dev/128.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#state::Google::Cloud::NetworkSecurity::V1::InterceptDeploymentGroup::State (readonly)

Returns Output only. The current state of the deployment group. See https://google.aip.dev/216.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 563

class InterceptDeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An endpoint group connected to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected endpoint group's resource name, for example:
  #     `projects/123456789/locations/global/interceptEndpointGroups/my-eg`.
  #     See https://google.aip.dev/124.
  class ConnectedEndpointGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A deployment belonging to this deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The name of the Intercept Deployment, in the format:
  #     `projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}`.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::InterceptDeployment::State]
  #     Output only. Most recent known state of the deployment.
  class Deployment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment group is ready.
    ACTIVE = 1

    # The deployment group is being created.
    CREATING = 2

    # The deployment group is being deleted.
    DELETING = 3
  end
end