Module: Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroup::State
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
Endpoint group state.
Constant Summary collapse
- STATE_UNSPECIFIED =
State not set (this is not a valid state).
0- ACTIVE =
The endpoint group is ready and in sync with the target deployment group.
1- CLOSED =
The deployment group backing this endpoint group has been force-deleted. This endpoint group cannot be used and interception is effectively disabled.
2- CREATING =
The endpoint group is being created.
3- DELETING =
The endpoint group is being deleted.
4- OUT_OF_SYNC =
The endpoint group is out of sync with the backing deployment group. In most cases, this is a result of a transient issue within the system (e.g. an inaccessible location) and the system is expected to recover automatically. See the associations field for details per network and location.
5- DELETE_FAILED =
An attempt to delete the endpoint group has failed. This is a terminal state and the endpoint group is not expected to recover. The only permitted operation is to retry deleting the endpoint group.
6