Module: Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State

Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

The state of association.

Constant Summary collapse

STATE_UNSPECIFIED =

Not set.

0
ACTIVE =

The association is ready and in sync with the linked endpoint group.

1
OUT_OF_SYNC =

The association is out of sync with the linked endpoint group. In most cases, this is a result of a transient issue within the system (e.g. an inaccessible location) and the system is expected to recover automatically.

2