Class: Google::Cloud::NetworkSecurity::V1::InterceptLocation
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::InterceptLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
Details about intercept in a specific cloud location.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#location ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::NetworkSecurity::V1::InterceptLocation::State
readonly
Output only.
Instance Attribute Details
#location ⇒ ::String (readonly)
Returns Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".
938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 938 class InterceptLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current state of a resource in the location. module State # State not set (this is not a valid state). STATE_UNSPECIFIED = 0 # The resource is ready and in sync in the location. ACTIVE = 1 # The resource is out of sync in the location. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end |
#state ⇒ ::Google::Cloud::NetworkSecurity::V1::InterceptLocation::State (readonly)
Returns Output only. The current state of the association in this location.
938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 938 class InterceptLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current state of a resource in the location. module State # State not set (this is not a valid state). STATE_UNSPECIFIED = 0 # The resource is ready and in sync in the location. ACTIVE = 1 # The resource is out of sync in the location. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end |