Module: Google::Cloud::NetworkSecurity::V1::InterceptLocation::State
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
The current state of a resource in the location.
Constant Summary collapse
- STATE_UNSPECIFIED =
State not set (this is not a valid state).
0- ACTIVE =
The resource is ready and in sync in the location.
1- OUT_OF_SYNC =
The resource is out of sync in the location. In most cases, this is a result of a transient issue within the system (e.g. an inaccessible location) and the system is expected to recover automatically.
2