Class: Google::Cloud::NetworkSecurity::V1::ListBackendAuthenticationConfigsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb

Overview

Request used by the ListBackendAuthenticationConfigs method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Maximum number of BackendAuthenticationConfigs to return per call.

Returns:

  • (::Integer)

    Maximum number of BackendAuthenticationConfigs to return per call.



132
133
134
135
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 132

class ListBackendAuthenticationConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns The value returned by the last ListBackendAuthenticationConfigsResponse Indicates that this is a continuation of a prior ListBackendAuthenticationConfigs call, and that the system should return the next page of data.

Returns:

  • (::String)

    The value returned by the last ListBackendAuthenticationConfigsResponse Indicates that this is a continuation of a prior ListBackendAuthenticationConfigs call, and that the system should return the next page of data.



132
133
134
135
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 132

class ListBackendAuthenticationConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The project and location from which the BackendAuthenticationConfigs should be listed, specified in the format projects/*/locations/{location}.

Returns:

  • (::String)

    Required. The project and location from which the BackendAuthenticationConfigs should be listed, specified in the format projects/*/locations/{location}.



132
133
134
135
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 132

class ListBackendAuthenticationConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end