Class: Google::Cloud::NetworkSecurity::V1::ListBackendAuthenticationConfigsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListBackendAuthenticationConfigsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb
Overview
Response returned by the ListBackendAuthenticationConfigs method.
Instance Attribute Summary collapse
-
#backend_authentication_configs ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig>
List of BackendAuthenticationConfig resources.
-
#next_page_token ⇒ ::String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#backend_authentication_configs ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig>
Returns List of BackendAuthenticationConfig resources.
149 150 151 152 |
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 149 class ListBackendAuthenticationConfigsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
149 150 151 152 |
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 149 class ListBackendAuthenticationConfigsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
149 150 151 152 |
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 149 class ListBackendAuthenticationConfigsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |