Class: Google::Cloud::NetworkSecurity::V1::ListFirewallEndpointAssociationsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb

Overview

Message for requesting list of Associations

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filtering results.

Returns:

  • (::String)

    Optional. Filtering results



351
352
353
354
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 351

class ListFirewallEndpointAssociationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Hint for how to order the results.

Returns:

  • (::String)

    Hint for how to order the results



351
352
353
354
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 351

class ListFirewallEndpointAssociationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



351
352
353
354
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 351

class ListFirewallEndpointAssociationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



351
352
353
354
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 351

class ListFirewallEndpointAssociationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListAssociationsRequest.

Returns:

  • (::String)

    Required. Parent value for ListAssociationsRequest



351
352
353
354
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 351

class ListFirewallEndpointAssociationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end