Class: Google::Cloud::NetworkSecurity::V1::ListFirewallEndpointsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListFirewallEndpointsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb
Overview
Message for response to listing Endpoints
Instance Attribute Summary collapse
-
#firewall_endpoints ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::FirewallEndpoint>
The list of Endpoint.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#firewall_endpoints ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::FirewallEndpoint>
Returns The list of Endpoint.
165 166 167 168 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 165 class ListFirewallEndpointsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
165 166 167 168 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 165 class ListFirewallEndpointsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
165 166 167 168 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 165 class ListFirewallEndpointsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |