Class: Google::Cloud::NetworkSecurity::V1::ListInterceptDeploymentGroupsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

Response message for ListInterceptDeploymentGroups.

Instance Attribute Summary collapse

Instance Attribute Details

#intercept_deployment_groups::Array<::Google::Cloud::NetworkSecurity::V1::InterceptDeploymentGroup>

Returns The deployment groups from the specified parent.

Returns:



656
657
658
659
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 656

class ListInterceptDeploymentGroupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.



656
657
658
659
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 656

class ListInterceptDeploymentGroupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end