Class: Google::Cloud::NetworkSecurity::V1::ListInterceptDeploymentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/intercept.rb

Overview

Response message for ListInterceptDeployments.

Instance Attribute Summary collapse

Instance Attribute Details

#intercept_deployments::Array<::Google::Cloud::NetworkSecurity::V1::InterceptDeployment>

Returns The deployments from the specified parent.

Returns:



859
860
861
862
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 859

class ListInterceptDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.



859
860
861
862
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 859

class ListInterceptDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



859
860
861
862
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 859

class ListInterceptDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end