Class: Google::Cloud::NetworkSecurity::V1::ListInterceptEndpointGroupAssociationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListInterceptEndpointGroupAssociationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
Response message for ListInterceptEndpointGroupAssociations.
Instance Attribute Summary collapse
-
#intercept_endpoint_group_associations ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation>
The associations from the specified parent.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#intercept_endpoint_group_associations ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation>
Returns The associations from the specified parent.
438 439 440 441 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 438 class ListInterceptEndpointGroupAssociationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
438 439 440 441 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 438 class ListInterceptEndpointGroupAssociationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |