Class: Google::Cloud::NetworkSecurity::V1::ListMirroringDeploymentGroupsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListMirroringDeploymentGroupsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/mirroring.rb
Overview
Response message for ListMirroringDeploymentGroups.
Instance Attribute Summary collapse
-
#mirroring_deployment_groups ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup>
The deployment groups from the specified parent.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#mirroring_deployment_groups ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup>
Returns The deployment groups from the specified parent.
666 667 668 669 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 666 class ListMirroringDeploymentGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
666 667 668 669 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 666 class ListMirroringDeploymentGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |