Class: Google::Cloud::NetworkSecurity::V1::ListMirroringDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListMirroringDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/mirroring.rb
Overview
Response message for ListMirroringDeployments.
Instance Attribute Summary collapse
-
#mirroring_deployments ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::MirroringDeployment>
The deployments from the specified parent.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page. -
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#mirroring_deployments ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::MirroringDeployment>
Returns The deployments from the specified parent.
869 870 871 872 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 869 class ListMirroringDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
869 870 871 872 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 869 class ListMirroringDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
869 870 871 872 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 869 class ListMirroringDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |