Class: Google::Cloud::NetworkSecurity::V1::ListMirroringEndpointGroupAssociationsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/mirroring.rb

Overview

Response message for ListMirroringEndpointGroupAssociations.

Instance Attribute Summary collapse

Instance Attribute Details

#mirroring_endpoint_group_associations::Array<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation>

Returns The associations from the specified parent.

Returns:



445
446
447
448
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 445

class ListMirroringEndpointGroupAssociationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.



445
446
447
448
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 445

class ListMirroringEndpointGroupAssociationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end