Class: Google::Cloud::NetworkSecurity::V1::ListMirroringEndpointGroupsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListMirroringEndpointGroupsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/mirroring.rb
Overview
Response message for ListMirroringEndpointGroups.
Instance Attribute Summary collapse
-
#mirroring_endpoint_groups ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup>
The endpoint groups from the specified parent.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#mirroring_endpoint_groups ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup>
Returns The endpoint groups from the specified parent.
206 207 208 209 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 206 class ListMirroringEndpointGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
206 207 208 209 |
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 206 class ListMirroringEndpointGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |