Class: Google::Cloud::NetworkSecurity::V1::ListSACAttachmentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/sse_realm.rb

Overview

Request for ListSACAttachments method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression that filters the list of results.

Returns:

  • (::String)

    Optional. An expression that filters the list of results.



293
294
295
296
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 293

class ListSACAttachmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Sort the results by a certain order.

Returns:

  • (::String)

    Optional. Sort the results by a certain order.



293
294
295
296
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 293

class ListSACAttachmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



293
294
295
296
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 293

class ListSACAttachmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



293
294
295
296
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 293

class ListSACAttachmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, in the form projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent, in the form projects/{project}/locations/{location}.



293
294
295
296
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 293

class ListSACAttachmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end