Class: Google::Cloud::NetworkSecurity::V1::ListSACAttachmentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListSACAttachmentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/sse_realm.rb
Overview
Response for ListSACAttachments method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#sac_attachments ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::SACAttachment>
The list of SACAttachments.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
308 309 310 311 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 308 class ListSACAttachmentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sac_attachments ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::SACAttachment>
Returns The list of SACAttachments.
308 309 310 311 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 308 class ListSACAttachmentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
308 309 310 311 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 308 class ListSACAttachmentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |