Class: Google::Cloud::NetworkSecurity::V1::ListSACRealmsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListSACRealmsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/sse_realm.rb
Overview
Response for ListSACRealms method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#sac_realms ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::SACRealm>
The list of SACRealms.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
139 140 141 142 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 139 class ListSACRealmsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sac_realms ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::SACRealm>
Returns The list of SACRealms.
139 140 141 142 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 139 class ListSACRealmsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
139 140 141 142 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 139 class ListSACRealmsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |