Class: Google::Cloud::NetworkSecurity::V1::ListServerTlsPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListServerTlsPoliciesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb
Overview
Response returned by the ListServerTlsPolicies method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#server_tls_policies ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::ServerTlsPolicy>
List of ServerTlsPolicy resources.
-
#unreachable ⇒ ::Array<::String>
Unreachable resources.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
188 189 190 191 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 188 class ListServerTlsPoliciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#server_tls_policies ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::ServerTlsPolicy>
Returns List of ServerTlsPolicy resources.
188 189 190 191 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 188 class ListServerTlsPoliciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable resources. Populated when the request opts into
return_partial_success and reading across collections e.g. when
attempting to list all resources across all supported locations.
188 189 190 191 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 188 class ListServerTlsPoliciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |