Class: Google::Cloud::NetworkSecurity::V1::ListTlsInspectionPoliciesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb

Overview

Request used with the ListTlsInspectionPolicies method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Maximum number of TlsInspectionPolicies to return per call.

Returns:

  • (::Integer)

    Maximum number of TlsInspectionPolicies to return per call.



173
174
175
176
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 173

class ListTlsInspectionPoliciesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns The value returned by the last 'ListTlsInspectionPoliciesResponse' Indicates that this is a continuation of a prior 'ListTlsInspectionPolicies' call, and that the system should return the next page of data.

Returns:

  • (::String)

    The value returned by the last 'ListTlsInspectionPoliciesResponse' Indicates that this is a continuation of a prior 'ListTlsInspectionPolicies' call, and that the system should return the next page of data.



173
174
175
176
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 173

class ListTlsInspectionPoliciesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The project and location from which the TlsInspectionPolicies should be listed, specified in the format projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The project and location from which the TlsInspectionPolicies should be listed, specified in the format projects/{project}/locations/{location}.



173
174
175
176
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 173

class ListTlsInspectionPoliciesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end