Class: Google::Cloud::NetworkSecurity::V1::ListUrlListsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/url_list.rb

Overview

Request used by the ListUrlList method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Maximum number of UrlLists to return per call.

Returns:

  • (::Integer)

    Maximum number of UrlLists to return per call.



65
66
67
68
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 65

class ListUrlListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns The value returned by the last ListUrlListsResponse Indicates that this is a continuation of a prior ListUrlLists call, and that the system should return the next page of data.

Returns:

  • (::String)

    The value returned by the last ListUrlListsResponse Indicates that this is a continuation of a prior ListUrlLists call, and that the system should return the next page of data.



65
66
67
68
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 65

class ListUrlListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The project and location from which the UrlLists should be listed, specified in the format projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The project and location from which the UrlLists should be listed, specified in the format projects/{project}/locations/{location}.



65
66
67
68
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 65

class ListUrlListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end