Class: Google::Cloud::NetworkSecurity::V1::ListUrlListsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/url_list.rb

Overview

Response returned by the ListUrlLists method.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token.

Returns:

  • (::String)

    If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token.



82
83
84
85
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 82

class ListUrlListsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



82
83
84
85
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 82

class ListUrlListsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url_lists::Array<::Google::Cloud::NetworkSecurity::V1::UrlList>

Returns List of UrlList resources.

Returns:



82
83
84
85
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 82

class ListUrlListsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end