Class: Google::Cloud::NetworkSecurity::V1::Mirroring::Client
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::Mirroring::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/network_security/v1/mirroring/client.rb
Overview
Client for the Mirroring service.
PM2 is the "out-of-band" flavor of the Network Security Integrations product.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::NetworkSecurity::V1::Mirroring::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Mirroring Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Mirroring Client instance.
-
#create_mirroring_deployment(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a deployment in a given project and location.
-
#create_mirroring_deployment_group(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a deployment group in a given project and location.
-
#create_mirroring_endpoint_group(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates an endpoint group in a given project and location.
-
#create_mirroring_endpoint_group_association(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates an association in a given project and location.
-
#delete_mirroring_deployment(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes a deployment.
-
#delete_mirroring_deployment_group(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes a deployment group.
-
#delete_mirroring_endpoint_group(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes an endpoint group.
-
#delete_mirroring_endpoint_group_association(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes an association.
-
#get_mirroring_deployment(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeployment
Gets a specific deployment.
-
#get_mirroring_deployment_group(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup
Gets a specific deployment group.
-
#get_mirroring_endpoint_group(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup
Gets a specific endpoint group.
-
#get_mirroring_endpoint_group_association(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation
Gets a specific association.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Mirroring client object.
-
#list_mirroring_deployment_groups(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup>
Lists deployment groups in a given project and location.
-
#list_mirroring_deployments(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringDeployment>
Lists deployments in a given project and location.
-
#list_mirroring_endpoint_group_associations(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation>
Lists associations in a given project and location.
-
#list_mirroring_endpoint_groups(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup>
Lists endpoint groups in a given project and location.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_mirroring_deployment(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates a deployment.
-
#update_mirroring_deployment_group(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates a deployment group.
-
#update_mirroring_endpoint_group(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates an endpoint group.
-
#update_mirroring_endpoint_group_association(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates an association.
Methods included from Paths
#forwarding_rule_path, #location_path, #mirroring_deployment_group_path, #mirroring_deployment_path, #mirroring_endpoint_group_association_path, #mirroring_endpoint_group_path, #network_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Mirroring client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 126 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/networksecurity/v1/mirroring_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @mirroring_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::NetworkSecurity::V1::Mirroring::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @mirroring_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @mirroring_stub.endpoint config.universe_domain = @mirroring_stub.universe_domain config.logger = @mirroring_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @mirroring_stub.endpoint config.universe_domain = @mirroring_stub.universe_domain config.logger = @mirroring_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
219 220 221 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 219 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
212 213 214 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 212 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::NetworkSecurity::V1::Mirroring::Operations (readonly)
Get the associated client for long-running operations.
205 206 207 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 205 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Mirroring Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "NetworkSecurity", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the Mirroring Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 96 def configure yield @config if block_given? @config end |
#create_mirroring_deployment(request, options = nil) ⇒ ::Gapic::Operation #create_mirroring_deployment(parent: nil, mirroring_deployment_id: nil, mirroring_deployment: nil, request_id: nil) ⇒ ::Gapic::Operation
Creates a deployment in a given project and location. See https://google.aip.dev/133.
2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 2014 def create_mirroring_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::CreateMirroringDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_mirroring_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_mirroring_deployment.timeout, metadata: , retry_policy: @config.rpcs.create_mirroring_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :create_mirroring_deployment, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_mirroring_deployment_group(request, options = nil) ⇒ ::Gapic::Operation #create_mirroring_deployment_group(parent: nil, mirroring_deployment_group_id: nil, mirroring_deployment_group: nil, request_id: nil) ⇒ ::Gapic::Operation
Creates a deployment group in a given project and location. See https://google.aip.dev/133.
1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1507 def create_mirroring_deployment_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::CreateMirroringDeploymentGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_mirroring_deployment_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_mirroring_deployment_group.timeout, metadata: , retry_policy: @config.rpcs.create_mirroring_deployment_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :create_mirroring_deployment_group, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_mirroring_endpoint_group(request, options = nil) ⇒ ::Gapic::Operation #create_mirroring_endpoint_group(parent: nil, mirroring_endpoint_group_id: nil, mirroring_endpoint_group: nil, request_id: nil) ⇒ ::Gapic::Operation
Creates an endpoint group in a given project and location. See https://google.aip.dev/133.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 493 def create_mirroring_endpoint_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::CreateMirroringEndpointGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_mirroring_endpoint_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_mirroring_endpoint_group.timeout, metadata: , retry_policy: @config.rpcs.create_mirroring_endpoint_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :create_mirroring_endpoint_group, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_mirroring_endpoint_group_association(request, options = nil) ⇒ ::Gapic::Operation #create_mirroring_endpoint_group_association(parent: nil, mirroring_endpoint_group_association_id: nil, mirroring_endpoint_group_association: nil, request_id: nil) ⇒ ::Gapic::Operation
Creates an association in a given project and location. See https://google.aip.dev/133.
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1000 def create_mirroring_endpoint_group_association request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::CreateMirroringEndpointGroupAssociationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_mirroring_endpoint_group_association..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_mirroring_endpoint_group_association.timeout, metadata: , retry_policy: @config.rpcs.create_mirroring_endpoint_group_association.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :create_mirroring_endpoint_group_association, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_mirroring_deployment(request, options = nil) ⇒ ::Gapic::Operation #delete_mirroring_deployment(name: nil, request_id: nil) ⇒ ::Gapic::Operation
Deletes a deployment. See https://google.aip.dev/135.
2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 2217 def delete_mirroring_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::DeleteMirroringDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_mirroring_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_mirroring_deployment.timeout, metadata: , retry_policy: @config.rpcs.delete_mirroring_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :delete_mirroring_deployment, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_mirroring_deployment_group(request, options = nil) ⇒ ::Gapic::Operation #delete_mirroring_deployment_group(name: nil, request_id: nil) ⇒ ::Gapic::Operation
Deletes a deployment group. See https://google.aip.dev/135.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1711 def delete_mirroring_deployment_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::DeleteMirroringDeploymentGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_mirroring_deployment_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_mirroring_deployment_group.timeout, metadata: , retry_policy: @config.rpcs.delete_mirroring_deployment_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :delete_mirroring_deployment_group, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_mirroring_endpoint_group(request, options = nil) ⇒ ::Gapic::Operation #delete_mirroring_endpoint_group(name: nil, request_id: nil) ⇒ ::Gapic::Operation
Deletes an endpoint group. See https://google.aip.dev/135.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 696 def delete_mirroring_endpoint_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::DeleteMirroringEndpointGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_mirroring_endpoint_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_mirroring_endpoint_group.timeout, metadata: , retry_policy: @config.rpcs.delete_mirroring_endpoint_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :delete_mirroring_endpoint_group, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_mirroring_endpoint_group_association(request, options = nil) ⇒ ::Gapic::Operation #delete_mirroring_endpoint_group_association(name: nil, request_id: nil) ⇒ ::Gapic::Operation
Deletes an association. See https://google.aip.dev/135.
1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1204 def delete_mirroring_endpoint_group_association request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::DeleteMirroringEndpointGroupAssociationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_mirroring_endpoint_group_association..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_mirroring_endpoint_group_association.timeout, metadata: , retry_policy: @config.rpcs.delete_mirroring_endpoint_group_association.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :delete_mirroring_endpoint_group_association, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_mirroring_deployment(request, options = nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeployment #get_mirroring_deployment(name: nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeployment
Gets a specific deployment. See https://google.aip.dev/131.
1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1911 def get_mirroring_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::GetMirroringDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_mirroring_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_mirroring_deployment.timeout, metadata: , retry_policy: @config.rpcs.get_mirroring_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :get_mirroring_deployment, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_mirroring_deployment_group(request, options = nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup #get_mirroring_deployment_group(name: nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup
Gets a specific deployment group. See https://google.aip.dev/131.
1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1404 def get_mirroring_deployment_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::GetMirroringDeploymentGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_mirroring_deployment_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_mirroring_deployment_group.timeout, metadata: , retry_policy: @config.rpcs.get_mirroring_deployment_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :get_mirroring_deployment_group, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_mirroring_endpoint_group(request, options = nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup #get_mirroring_endpoint_group(name: nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup
Gets a specific endpoint group. See https://google.aip.dev/131.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 390 def get_mirroring_endpoint_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::GetMirroringEndpointGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_mirroring_endpoint_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_mirroring_endpoint_group.timeout, metadata: , retry_policy: @config.rpcs.get_mirroring_endpoint_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :get_mirroring_endpoint_group, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_mirroring_endpoint_group_association(request, options = nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation #get_mirroring_endpoint_group_association(name: nil) ⇒ ::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation
Gets a specific association. See https://google.aip.dev/131.
896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 896 def get_mirroring_endpoint_group_association request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::GetMirroringEndpointGroupAssociationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_mirroring_endpoint_group_association..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_mirroring_endpoint_group_association.timeout, metadata: , retry_policy: @config.rpcs.get_mirroring_endpoint_group_association.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :get_mirroring_endpoint_group_association, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_mirroring_deployment_groups(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup> #list_mirroring_deployment_groups(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup>
Lists deployment groups in a given project and location. See https://google.aip.dev/132.
1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1314 def list_mirroring_deployment_groups request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::ListMirroringDeploymentGroupsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_mirroring_deployment_groups..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_mirroring_deployment_groups.timeout, metadata: , retry_policy: @config.rpcs.list_mirroring_deployment_groups.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :list_mirroring_deployment_groups, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @mirroring_stub, :list_mirroring_deployment_groups, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_mirroring_deployments(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringDeployment> #list_mirroring_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringDeployment>
Lists deployments in a given project and location. See https://google.aip.dev/132.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1821 def list_mirroring_deployments request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::ListMirroringDeploymentsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_mirroring_deployments..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_mirroring_deployments.timeout, metadata: , retry_policy: @config.rpcs.list_mirroring_deployments.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :list_mirroring_deployments, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @mirroring_stub, :list_mirroring_deployments, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_mirroring_endpoint_group_associations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation> #list_mirroring_endpoint_group_associations(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation>
Lists associations in a given project and location. See https://google.aip.dev/132.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 806 def list_mirroring_endpoint_group_associations request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::ListMirroringEndpointGroupAssociationsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_mirroring_endpoint_group_associations..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_mirroring_endpoint_group_associations.timeout, metadata: , retry_policy: @config.rpcs.list_mirroring_endpoint_group_associations.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :list_mirroring_endpoint_group_associations, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @mirroring_stub, :list_mirroring_endpoint_group_associations, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_mirroring_endpoint_groups(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup> #list_mirroring_endpoint_groups(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup>
Lists endpoint groups in a given project and location. See https://google.aip.dev/132.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 300 def list_mirroring_endpoint_groups request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::ListMirroringEndpointGroupsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_mirroring_endpoint_groups..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_mirroring_endpoint_groups.timeout, metadata: , retry_policy: @config.rpcs.list_mirroring_endpoint_groups.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :list_mirroring_endpoint_groups, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @mirroring_stub, :list_mirroring_endpoint_groups, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
226 227 228 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 226 def logger @mirroring_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 106 def universe_domain @mirroring_stub.universe_domain end |
#update_mirroring_deployment(request, options = nil) ⇒ ::Gapic::Operation #update_mirroring_deployment(update_mask: nil, mirroring_deployment: nil, request_id: nil) ⇒ ::Gapic::Operation
Updates a deployment. See https://google.aip.dev/134.
2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 2118 def update_mirroring_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::UpdateMirroringDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_mirroring_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.mirroring_deployment&.name header_params["mirroring_deployment.name"] = request.mirroring_deployment.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_mirroring_deployment.timeout, metadata: , retry_policy: @config.rpcs.update_mirroring_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :update_mirroring_deployment, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_mirroring_deployment_group(request, options = nil) ⇒ ::Gapic::Operation #update_mirroring_deployment_group(update_mask: nil, mirroring_deployment_group: nil, request_id: nil) ⇒ ::Gapic::Operation
Updates a deployment group. See https://google.aip.dev/134.
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1612 def update_mirroring_deployment_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::UpdateMirroringDeploymentGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_mirroring_deployment_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.mirroring_deployment_group&.name header_params["mirroring_deployment_group.name"] = request.mirroring_deployment_group.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_mirroring_deployment_group.timeout, metadata: , retry_policy: @config.rpcs.update_mirroring_deployment_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :update_mirroring_deployment_group, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_mirroring_endpoint_group(request, options = nil) ⇒ ::Gapic::Operation #update_mirroring_endpoint_group(update_mask: nil, mirroring_endpoint_group: nil, request_id: nil) ⇒ ::Gapic::Operation
Updates an endpoint group. See https://google.aip.dev/134.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 597 def update_mirroring_endpoint_group request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::UpdateMirroringEndpointGroupRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_mirroring_endpoint_group..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.mirroring_endpoint_group&.name header_params["mirroring_endpoint_group.name"] = request.mirroring_endpoint_group.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_mirroring_endpoint_group.timeout, metadata: , retry_policy: @config.rpcs.update_mirroring_endpoint_group.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :update_mirroring_endpoint_group, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_mirroring_endpoint_group_association(request, options = nil) ⇒ ::Gapic::Operation #update_mirroring_endpoint_group_association(update_mask: nil, mirroring_endpoint_group_association: nil, request_id: nil) ⇒ ::Gapic::Operation
Updates an association. See https://google.aip.dev/134.
1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'lib/google/cloud/network_security/v1/mirroring/client.rb', line 1105 def update_mirroring_endpoint_group_association request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkSecurity::V1::UpdateMirroringEndpointGroupAssociationRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_mirroring_endpoint_group_association..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkSecurity::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.mirroring_endpoint_group_association&.name header_params["mirroring_endpoint_group_association.name"] = request.mirroring_endpoint_group_association.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_mirroring_endpoint_group_association.timeout, metadata: , retry_policy: @config.rpcs.update_mirroring_endpoint_group_association.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @mirroring_stub.call_rpc :update_mirroring_endpoint_group_association, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |