Class: Google::Cloud::NetworkSecurity::V1::MirroringDeployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/mirroring.rb

Overview

A deployment represents a zonal mirroring backend ready to accept GENEVE-encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.

Defined Under Namespace

Modules: State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

Returns:



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#description::String

Returns Optional. User-provided description of the deployment. Used as additional context for the deployment.

Returns:

  • (::String)

    Optional. User-provided description of the deployment. Used as additional context for the deployment.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#forwarding_rule::String

Returns Required. Immutable. The regional forwarding rule that fronts the mirroring collectors, for example: projects/123456789/regions/us-central1/forwardingRules/my-rule. See https://google.aip.dev/124.

Returns:

  • (::String)

    Required. Immutable. The regional forwarding rule that fronts the mirroring collectors, for example: projects/123456789/regions/us-central1/forwardingRules/my-rule. See https://google.aip.dev/124.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels are key/value pairs that help to organize and filter resources.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels are key/value pairs that help to organize and filter resources.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#mirroring_deployment_group::String

Returns Required. Immutable. The deployment group that this deployment is a part of, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.

Returns:

  • (::String)

    Required. Immutable. The deployment group that this deployment is a part of, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#name::String

Returns Immutable. Identifier. The resource name of this deployment, for example: projects/123456789/locations/us-central1-a/mirroringDeployments/my-dep. See https://google.aip.dev/122 for more details.

Returns:

  • (::String)

    Immutable. Identifier. The resource name of this deployment, for example: projects/123456789/locations/us-central1-a/mirroringDeployments/my-dep. See https://google.aip.dev/122 for more details.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#reconciling::Boolean (readonly)

Returns Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. linking a new association to the parent group). See https://google.aip.dev/128.

Returns:

  • (::Boolean)

    Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. linking a new association to the parent group). See https://google.aip.dev/128.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#state::Google::Cloud::NetworkSecurity::V1::MirroringDeployment::State (readonly)

Returns Output only. The current state of the deployment. See https://google.aip.dev/216.

Returns:



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.

Returns:



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 786

class MirroringDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the deployment.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The deployment is ready and in sync with the parent group.
    ACTIVE = 1

    # The deployment is being created.
    CREATING = 2

    # The deployment is being deleted.
    DELETING = 3

    # The deployment is out of sync with the parent group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. a delayed data-path config) and the system is expected to recover
    # automatically. See the parent deployment group's state for more details.
    OUT_OF_SYNC = 4

    # An attempt to delete the deployment has failed. This is a terminal state
    # and the deployment is not expected to recover. The only permitted
    # operation is to retry deleting the deployment.
    DELETE_FAILED = 5
  end
end