Class: Google::Cloud::NetworkSecurity::V1::MirroringDeploymentGroup::Deployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/mirroring.rb

Overview

A deployment belonging to this deployment group.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String (readonly)

Returns Output only. The name of the Mirroring Deployment, in the format: projects/{project}/locations/{location}/mirroringDeployments/{mirroring_deployment}.

Returns:

  • (::String)

    Output only. The name of the Mirroring Deployment, in the format: projects/{project}/locations/{location}/mirroringDeployments/{mirroring_deployment}.



593
594
595
596
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 593

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#state::Google::Cloud::NetworkSecurity::V1::MirroringDeployment::State (readonly)

Returns Output only. Most recent known state of the deployment.

Returns:



593
594
595
596
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 593

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end