Class: Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/mirroring.rb

Overview

An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create:

  • An association between their network and the endpoint group.
  • A security profile that points to the endpoint group.
  • A mirroring rule that references the security profile (group).

Defined Under Namespace

Modules: State, Type Classes: AssociationDetails, ConnectedDeploymentGroup, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#associations::Array<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup::AssociationDetails> (readonly)

Returns Output only. List of associations to this endpoint group.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#connected_deployment_groups::Array<::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup::ConnectedDeploymentGroup> (readonly)

Returns Output only. List of details about the connected deployment groups to this endpoint group.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#description::String

Returns Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group.

Returns:

  • (::String)

    Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels are key/value pairs that help to organize and filter resources.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels are key/value pairs that help to organize and filter resources.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#mirroring_deployment_group::String

Returns Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.

Returns:

  • (::String)

    Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#name::String

Returns Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/122 for more details.

Returns:

  • (::String)

    Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/122 for more details.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#reconciling::Boolean (readonly)

Returns Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https://google.aip.dev/128.

Returns:

  • (::Boolean)

    Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https://google.aip.dev/128.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#state::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup::State (readonly)

Returns Output only. The current state of the endpoint group. See https://google.aip.dev/216.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#type::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroup::Type

Returns Immutable. The type of the endpoint group. If left unspecified, defaults to DIRECT.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 78

class MirroringEndpointGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The endpoint group's view of a connected deployment group.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected deployment group's resource name, for example:
  #     `projects/123456789/locations/global/mirroringDeploymentGroups/my-dg`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] locations
  #   @return [::Array<::Google::Cloud::NetworkSecurity::V1::MirroringLocation>]
  #     Output only. The list of locations where the deployment group is present.
  class ConnectedDeploymentGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The endpoint group's view of a connected association.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The connected association's resource name, for example:
  #     `projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-ega`.
  #     See https://google.aip.dev/124.
  # @!attribute [r] network
  #   @return [::String]
  #     Output only. The associated network, for example:
  #     projects/123456789/global/networks/my-network.
  #     See https://google.aip.dev/124.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::State]
  #     Output only. Most recent known state of the association.
  class AssociationDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the endpoint group.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The endpoint group is ready and in sync with the target deployment group.
    ACTIVE = 1

    # The deployment group backing this endpoint group has been force-deleted.
    # This endpoint group cannot be used and mirroring is effectively disabled.
    CLOSED = 2

    # The endpoint group is being created.
    CREATING = 3

    # The endpoint group is being deleted.
    DELETING = 4

    # The endpoint group is out of sync with the backing deployment group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically. See the associations field for details per network and
    # location.
    OUT_OF_SYNC = 5

    # An attempt to delete the endpoint group has failed. This is a terminal
    # state and the endpoint group is not expected to recover.
    # The only permitted operation is to retry deleting the endpoint group.
    DELETE_FAILED = 6
  end

  # The type of the endpoint group.
  module Type
    # Not set.
    TYPE_UNSPECIFIED = 0

    # An endpoint group that sends packets to a single deployment group.
    DIRECT = 1
  end
end