Class: Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::LocationDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/mirroring.rb

Overview

Contains details about the state of an association in a specific cloud location.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#location::String (readonly)

Returns Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".

Returns:

  • (::String)

    Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 345

class LocationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of association.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The association is ready and in sync with the linked endpoint group.
    ACTIVE = 1

    # The association is out of sync with the linked endpoint group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically.
    OUT_OF_SYNC = 2
  end
end

#state::Google::Cloud::NetworkSecurity::V1::MirroringEndpointGroupAssociation::LocationDetails::State (readonly)

Returns Output only. The current state of the association in this location.

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 345

class LocationDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of association.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The association is ready and in sync with the linked endpoint group.
    ACTIVE = 1

    # The association is out of sync with the linked endpoint group.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically.
    OUT_OF_SYNC = 2
  end
end