Class: Google::Cloud::NetworkSecurity::V1::MirroringLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/mirroring.rb

Overview

Details about mirroring in a specific cloud location.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#location::String (readonly)

Returns Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".

Returns:

  • (::String)

    Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".



948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 948

class MirroringLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The current state of a resource in the location.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The resource is ready and in sync in the location.
    ACTIVE = 1

    # The resource is out of sync in the location.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically.
    OUT_OF_SYNC = 2
  end
end

#state::Google::Cloud::NetworkSecurity::V1::MirroringLocation::State (readonly)

Returns Output only. The current state of the association in this location.

Returns:



948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'proto_docs/google/cloud/networksecurity/v1/mirroring.rb', line 948

class MirroringLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The current state of a resource in the location.
  module State
    # State not set (this is not a valid state).
    STATE_UNSPECIFIED = 0

    # The resource is ready and in sync in the location.
    ACTIVE = 1

    # The resource is out of sync in the location.
    # In most cases, this is a result of a transient issue within the system
    # (e.g. an inaccessible location) and the system is expected to recover
    # automatically.
    OUT_OF_SYNC = 2
  end
end