Class: Google::Cloud::NetworkSecurity::V1::SACAttachment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/sse_realm.rb

Overview

Represents a Secure Access Connect (SAC) attachment resource.

A Secure Access Connect attachment enables NCC Gateway to process traffic with an SSE product.

Defined Under Namespace

Modules: State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the attachment was created.

Returns:



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Optional list of labels applied to the resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Optional list of labels applied to the resource.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end

#name::String

Returns Identifier. Resource name, in the form projects/{project}/locations/{location}/sacAttachments/{sac_attachment}.

Returns:

  • (::String)

    Identifier. Resource name, in the form projects/{project}/locations/{location}/sacAttachments/{sac_attachment}.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end

#ncc_gateway::String

Returns Required. NCC Gateway associated with the attachment. This can be input as an ID or a full resource name. The output always has the form projects/{project_number}/locations/{location}/spokes/{ncc_gateway}.

Returns:

  • (::String)

    Required. NCC Gateway associated with the attachment. This can be input as an ID or a full resource name. The output always has the form projects/{project_number}/locations/{location}/spokes/{ncc_gateway}.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end

#sac_realm::String

Returns Required. SAC Realm which owns the attachment. This can be input as an ID or a full resource name. The output always has the form projects/{project_number}/locations/{location}/sacRealms/{sac_realm}.

Returns:

  • (::String)

    Required. SAC Realm which owns the attachment. This can be input as an ID or a full resource name. The output always has the form projects/{project_number}/locations/{location}/sacRealms/{sac_realm}.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end

#state::Google::Cloud::NetworkSecurity::V1::SACAttachment::State (readonly)

Returns Output only. State of the attachment.

Returns:



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the attachment was last updated.

Returns:



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 246

class SACAttachment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the attachment.
  module State
    # No state specified. This should not be used.
    STATE_UNSPECIFIED = 0

    # Has never been attached to a partner.
    PENDING_PARTNER_ATTACHMENT = 1

    # Currently attached to a partner.
    PARTNER_ATTACHED = 2

    # Was once attached to a partner but has been detached.
    PARTNER_DETACHED = 3
  end
end