Module: Google::Cloud::NetworkSecurity::V1::SACRealm::State

Defined in:
proto_docs/google/cloud/networksecurity/v1/sse_realm.rb

Overview

State of the realm.

Constant Summary collapse

STATE_UNSPECIFIED =

No state specified. This should not be used.

0
PENDING_PARTNER_ATTACHMENT =

Has never been attached to a partner. Used only for Prisma Access.

7
PARTNER_ATTACHED =

Currently attached to a partner.

1
PARTNER_DETACHED =

Was once attached to a partner but has been detached.

2
KEY_EXPIRED =

Is not attached to a partner and has an expired pairing key. Used only for Prisma Access.

3