Module: Google::Cloud::NetworkSecurity::V1::ServerTlsPolicy::MTLSPolicy::ClientValidationMode

Defined in:
proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb

Overview

Mutual TLS certificate validation mode.

Constant Summary collapse

CLIENT_VALIDATION_MODE_UNSPECIFIED =

Not allowed.

0
ALLOW_INVALID_OR_MISSING_CLIENT_CERT =

Allow connection even if certificate chain validation of the client certificate failed or no client certificate was presented. The proof of possession of the private key is always checked if client certificate was presented. This mode requires the backend to implement processing of data extracted from a client certificate to authenticate the peer, or to reject connections if the client certificate fingerprint is missing.

1
REJECT_INVALID =

Require a client certificate and allow connection to the backend only if validation of the client certificate passed.

If set, requires a reference to non-empty TrustConfig specified in client_validation_trust_config.

2