Class: Google::Cloud::NetworkSecurity::V1::ThreatOverride

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb

Overview

Defines what action to take for a specific threat_id match.

Instance Attribute Summary collapse

Instance Attribute Details

#action::Google::Cloud::NetworkSecurity::V1::ThreatAction

Returns Required. Threat action override. For some threat types, only a subset of actions applies.

Returns:



65
66
67
68
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 65

class ThreatOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#threat_id::String

Returns Required. Vendor-specific ID of a threat to override.

Returns:

  • (::String)

    Required. Vendor-specific ID of a threat to override.



65
66
67
68
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 65

class ThreatOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::Google::Cloud::NetworkSecurity::V1::ThreatType (readonly)

Returns Output only. Type of the threat (read only).

Returns:



65
66
67
68
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 65

class ThreatOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end