Class: Google::Cloud::NetworkSecurity::V1::ThreatPreventionProfile
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ThreatPreventionProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb
Overview
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
Instance Attribute Summary collapse
-
#antivirus_overrides ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::AntivirusOverride>
Optional.
-
#severity_overrides ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::SeverityOverride>
Optional.
-
#threat_overrides ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::ThreatOverride>
Optional.
Instance Attribute Details
#antivirus_overrides ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::AntivirusOverride>
Returns Optional. Configuration for overriding antivirus actions per protocol.
37 38 39 40 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 37 class ThreatPreventionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#severity_overrides ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::SeverityOverride>
Returns Optional. Configuration for overriding threats actions by severity match.
37 38 39 40 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 37 class ThreatPreventionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#threat_overrides ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::ThreatOverride>
Returns Optional. Configuration for overriding threats actions by threat_id match. If a threat is matched both by configuration provided in severity_overrides and threat_overrides, the threat_overrides action is applied.
37 38 39 40 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 37 class ThreatPreventionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |