Module: Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy::Profile

Defined in:
proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb

Overview

Profile specifies the set of TLS cipher suites (and possibly other features in the future) that can be used by the firewall when negotiating TLS connections with clients and servers. The meaning of these fields is identical to the load balancers' SSLPolicy resource.

Constant Summary collapse

PROFILE_UNSPECIFIED =

Indicates no profile was specified.

0
PROFILE_COMPATIBLE =

Compatible profile. Allows the broadest set of clients, even those which support only out-of-date SSL features to negotiate with the TLS inspection proxy.

1
PROFILE_MODERN =

Modern profile. Supports a wide set of SSL features, allowing modern clients to negotiate SSL with the TLS inspection proxy.

2
PROFILE_RESTRICTED =

Restricted profile. Supports a reduced set of SSL features, intended to meet stricter compliance requirements.

3
PROFILE_CUSTOM =

Custom profile. Allow only the set of allowed SSL features specified in the custom_features field of SslPolicy.

4