Module: Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy::TlsVersion

Defined in:
proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb

Overview

The minimum version of TLS protocol that can be used by clients or servers to establish a connection with the TLS inspection proxy.

Constant Summary collapse

TLS_VERSION_UNSPECIFIED =

Indicates no TLS version was specified.

0
TLS_1_0 =

TLS 1.0

1
TLS_1_1 =

TLS 1.1

2
TLS_1_2 =

TLS 1.2

3
TLS_1_3 =

TLS 1.3

4