Class: Google::Cloud::NetworkSecurity::V1::UpdateAuthzPolicyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::UpdateAuthzPolicyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/authz_policy.rb
Overview
Message for updating an AuthzPolicy resource.
Instance Attribute Summary collapse
-
#authz_policy ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy
Required.
-
#request_id ⇒ ::String
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Required.
Instance Attribute Details
#authz_policy ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy
Returns Required. AuthzPolicy resource being updated.
702 703 704 705 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 702 class UpdateAuthzPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
702 703 704 705 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 702 class UpdateAuthzPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Required. Used to specify the fields to be overwritten in the
AuthzPolicy resource by the update.
The fields specified in the update_mask are relative to the resource, not
the full request. A field is overwritten if it is in the mask. If the
user does not specify a mask, then all fields are overwritten.
702 703 704 705 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 702 class UpdateAuthzPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |