Class: Google::Cloud::NetworkSecurity::V1::UpdateBackendAuthenticationConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb

Overview

Request used by UpdateBackendAuthenticationConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#backend_authentication_config::Google::Cloud::NetworkSecurity::V1::BackendAuthenticationConfig

Returns Required. Updated BackendAuthenticationConfig resource.

Returns:



195
196
197
198
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 195

class UpdateBackendAuthenticationConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to specify the fields to be overwritten in the BackendAuthenticationConfig resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to specify the fields to be overwritten in the BackendAuthenticationConfig resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.



195
196
197
198
# File 'proto_docs/google/cloud/networksecurity/v1/backend_authentication_config.rb', line 195

class UpdateBackendAuthenticationConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end