Class: Google::Cloud::NetworkSecurity::V1::UpdateGatewaySecurityPolicyRuleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::UpdateGatewaySecurityPolicyRuleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb
Overview
Request used by the UpdateGatewaySecurityPolicyRule method.
Instance Attribute Summary collapse
-
#gateway_security_policy_rule ⇒ ::Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicyRule
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#gateway_security_policy_rule ⇒ ::Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicyRule
Returns Required. Updated GatewaySecurityPolicyRule resource.
123 124 125 126 |
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 123 class UpdateGatewaySecurityPolicyRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the GatewaySecurityPolicy resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
123 124 125 126 |
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 123 class UpdateGatewaySecurityPolicyRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |