Class: Google::Cloud::NetworkSecurity::V1::UpdateUrlListRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::UpdateUrlListRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/url_list.rb
Overview
Request used by UpdateUrlList method.
Instance Attribute Summary collapse
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
-
#url_list ⇒ ::Google::Cloud::NetworkSecurity::V1::UrlList
Required.
Instance Attribute Details
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the UrlList resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
127 128 129 130 |
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 127 class UpdateUrlListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url_list ⇒ ::Google::Cloud::NetworkSecurity::V1::UrlList
Returns Required. Updated UrlList resource.
127 128 129 130 |
# File 'proto_docs/google/cloud/networksecurity/v1/url_list.rb', line 127 class UpdateUrlListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |