Class: Google::Cloud::NetworkSecurity::V1::AntivirusOverride
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::AntivirusOverride
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb
Overview
Defines what action to take for antivirus threats per protocol.
Instance Attribute Summary collapse
-
#action ⇒ ::Google::Cloud::NetworkSecurity::V1::ThreatAction
Required.
-
#protocol ⇒ ::Google::Cloud::NetworkSecurity::V1::Protocol
Required.
Instance Attribute Details
#action ⇒ ::Google::Cloud::NetworkSecurity::V1::ThreatAction
Returns Required. Threat action override. For some threat types, only a subset of actions applies.
78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 78 class AntivirusOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#protocol ⇒ ::Google::Cloud::NetworkSecurity::V1::Protocol
Returns Required. Protocol to match.
78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb', line 78 class AntivirusOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |