Class: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/authz_policy.rb
Overview
Allows delegating authorization decisions to Cloud IAP or to Service Extensions.
Defined Under Namespace
Classes: AuthzExtension, CloudIap
Instance Attribute Summary collapse
-
#authz_extension ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider::AuthzExtension
Optional.
-
#cloud_iap ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider::CloudIap
Optional.
Instance Attribute Details
#authz_extension ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider::AuthzExtension
Returns Optional. Delegate authorization decision to user authored Service Extension. Only one of cloudIap or authzExtension can be specified.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 499 class CustomProvider include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Delegates authorization decisions to Cloud IAP. Applicable # only for managed load balancers. Enabling Cloud IAP at the AuthzPolicy # level is not compatible with Cloud IAP settings in the BackendService. # Enabling IAP in both places will result in request failure. Ensure that # IAP is enabled in either the AuthzPolicy or the BackendService but not in # both places. class CloudIap include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Delegate authorization decision to user authored extension. # Only one of cloudIap or authzExtension can be specified. # @!attribute [rw] resources # @return [::Array<::String>] # Required. A list of references to authorization # extensions that will be invoked for requests matching this policy. # Limited to 1 custom provider. class AuthzExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#cloud_iap ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::CustomProvider::CloudIap
Returns Optional. Delegates authorization decisions to Cloud IAP. Applicable only for managed load balancers. Enabling Cloud IAP at the AuthzPolicy level is not compatible with Cloud IAP settings in the BackendService. Enabling IAP in both places will result in request failure. Ensure that IAP is enabled in either the AuthzPolicy or the BackendService but not in both places.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 499 class CustomProvider include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Delegates authorization decisions to Cloud IAP. Applicable # only for managed load balancers. Enabling Cloud IAP at the AuthzPolicy # level is not compatible with Cloud IAP settings in the BackendService. # Enabling IAP in both places will result in request failure. Ensure that # IAP is enabled in either the AuthzPolicy or the BackendService but not in # both places. class CloudIap include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Delegate authorization decision to user authored extension. # Only one of cloudIap or authzExtension can be specified. # @!attribute [rw] resources # @return [::Array<::String>] # Required. A list of references to authorization # extensions that will be invoked for requests matching this policy. # Limited to 1 custom provider. class AuthzExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |