Class: Google::Cloud::NetworkSecurity::V1::AuthzPolicy::Target
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::AuthzPolicy::Target
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/authz_policy.rb
Overview
Specifies the set of targets to which this policy should be applied to.
Instance Attribute Summary collapse
-
#load_balancing_scheme ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::LoadBalancingScheme
Optional.
-
#resources ⇒ ::Array<::String>
Required.
Instance Attribute Details
#load_balancing_scheme ⇒ ::Google::Cloud::NetworkSecurity::V1::AuthzPolicy::LoadBalancingScheme
Returns Optional. All gateways and forwarding rules referenced by this policy and
extensions must share the same load balancing scheme. Required only when
targeting forwarding rules. If targeting Secure Web Proxy, this field
must be INTERNAL_MANAGED or not specified. Must not be specified
when targeting Agent Gateway. Supported values:
INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer
to Backend services
overview.
120 121 122 123 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 120 class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resources ⇒ ::Array<::String>
Returns Required. A list of references to the Forwarding Rules, Secure Web Proxy Gateways, or Agent Gateways on which this policy will be applied.
120 121 122 123 |
# File 'proto_docs/google/cloud/networksecurity/v1/authz_policy.rb', line 120 class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |