Class: Google::Cloud::NetworkSecurity::V1::CreateAddressGroupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateAddressGroupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/address_group.rb
Overview
Request used by the CreateAddressGroup method.
Instance Attribute Summary collapse
-
#address_group ⇒ ::Google::Cloud::NetworkSecurity::V1::AddressGroup
Required.
-
#address_group_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#address_group ⇒ ::Google::Cloud::NetworkSecurity::V1::AddressGroup
Returns Required. AddressGroup resource to be created.
177 178 179 180 |
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 177 class CreateAddressGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#address_group_id ⇒ ::String
Returns Required. Short name of the AddressGroup resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. "authz_policy".
177 178 179 180 |
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 177 class CreateAddressGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource of the AddressGroup. Must be in the
format projects/*/locations/{location}.
177 178 179 180 |
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 177 class CreateAddressGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
177 178 179 180 |
# File 'proto_docs/google/cloud/networksecurity/v1/address_group.rb', line 177 class CreateAddressGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |