Class: Google::Cloud::NetworkSecurity::V1::CreateGatewaySecurityPolicyRuleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateGatewaySecurityPolicyRuleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb
Overview
Methods for GatewaySecurityPolicy RULES/GatewaySecurityPolicyRules. Request used by the CreateGatewaySecurityPolicyRule method.
Instance Attribute Summary collapse
-
#gateway_security_policy_rule ⇒ ::Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicyRule
Required.
-
#gateway_security_policy_rule_id ⇒ ::String
The ID to use for the rule, which will become the final component of the rule's resource name.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#gateway_security_policy_rule ⇒ ::Google::Cloud::NetworkSecurity::V1::GatewaySecurityPolicyRule
Returns Required. The rule to be created.
96 97 98 99 |
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 96 class CreateGatewaySecurityPolicyRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gateway_security_policy_rule_id ⇒ ::String
Returns The ID to use for the rule, which will become the final component of the rule's resource name. This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/.
96 97 98 99 |
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 96 class CreateGatewaySecurityPolicyRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent where this rule will be created. Format : projects/{project}/location/{location}/gatewaySecurityPolicies/*.
96 97 98 99 |
# File 'proto_docs/google/cloud/networksecurity/v1/gateway_security_policy_rule.rb', line 96 class CreateGatewaySecurityPolicyRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |