Class: Google::Cloud::NetworkSecurity::V1::CreateSACRealmRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::CreateSACRealmRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/sse_realm.rb
Overview
Request for CreateSACRealm method.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
-
#sac_realm ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm
Required.
-
#sac_realm_id ⇒ ::String
Required.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent, in the form projects/{project}/locations/global.
186 187 188 189 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 186 class CreateSACRealmRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
186 187 188 189 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 186 class CreateSACRealmRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sac_realm ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm
Returns Required. The resource being created.
186 187 188 189 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 186 class CreateSACRealmRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sac_realm_id ⇒ ::String
Returns Required. ID of the created realm.
The ID must be 1-63 characters long, and comply with
RFC1035.
Specifically, it must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
186 187 188 189 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 186 class CreateSACRealmRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |