Class: Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
An endpoint group association represents a link between a network and an endpoint group in the organization.
Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable intercept by itself. To enable intercept, the user must also create a network firewall policy containing intercept rules and associate it with the network.
Defined Under Namespace
Modules: State Classes: LabelsEntry, LocationDetails
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#intercept_endpoint_group ⇒ ::String
Required.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#locations ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptLocation>
readonly
Output only.
-
#locations_details ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails>
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#name ⇒ ::String
Immutable.
-
#network ⇒ ::String
Required.
-
#network_cookie ⇒ ::Integer
readonly
Output only.
-
#reconciling ⇒ ::Boolean
readonly
Output only.
-
#state ⇒ ::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#intercept_endpoint_group ⇒ ::String
Returns Required. Immutable. The endpoint group that this association is connected
to, for example:
projects/123456789/locations/global/interceptEndpointGroups/my-eg.
See https://google.aip.dev/124.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels are key/value pairs that help to organize and filter resources.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#locations ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptLocation> (readonly)
Returns Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#locations_details ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails> (readonly)
This field is deprecated and may be removed in the next major version update.
Returns Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#name ⇒ ::String
Returns Immutable. Identifier. The resource name of this endpoint group
association, for example:
projects/123456789/locations/global/interceptEndpointGroupAssociations/my-eg-association.
See https://google.aip.dev/122 for more details.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#network ⇒ ::String
Returns Required. Immutable. The VPC network that is associated. for example:
projects/123456789/global/networks/my-network.
See https://google.aip.dev/124.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#network_cookie ⇒ ::Integer (readonly)
Returns Output only. Identifier used by the data-path. See the NSI GENEVE format for more details: https://docs.cloud.google.com/network-security-integration/docs/understand-geneve#network_id.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#reconciling ⇒ ::Boolean (readonly)
Returns Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#state ⇒ ::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::State (readonly)
Returns Output only. Current state of the endpoint group association.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 326 class InterceptEndpointGroupAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains details about the state of an association in a specific cloud # location. # @!attribute [r] location # @return [::String] # Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". # @!attribute [r] state # @return [::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::LocationDetails::State] # Output only. The current state of the association in this location. class LocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. OUT_OF_SYNC = 2 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the association. module State # Not set. STATE_UNSPECIFIED = 0 # The association is ready and in sync with the linked endpoint group. ACTIVE = 1 # The association is being created. CREATING = 2 # The association is being deleted. DELETING = 3 # The association is disabled due to a breaking change in another resource. CLOSED = 4 # The association is out of sync with the linked endpoint group. # In most cases, this is a result of a transient issue within the system # (e.g. an inaccessible location) and the system is expected to recover # automatically. Check the `locations_details` field for more details. OUT_OF_SYNC = 5 # An attempt to delete the association has failed. This is a terminal state # and the association is not expected to be usable as some of its resources # have been deleted. # The only permitted operation is to retry deleting the association. DELETE_FAILED = 6 end end |