Module: Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroupAssociation::State
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
The state of the association.
Constant Summary collapse
- STATE_UNSPECIFIED =
Not set.
0- ACTIVE =
The association is ready and in sync with the linked endpoint group.
1- CREATING =
The association is being created.
2- DELETING =
The association is being deleted.
3- CLOSED =
The association is disabled due to a breaking change in another resource.
4- OUT_OF_SYNC =
The association is out of sync with the linked endpoint group. In most cases, this is a result of a transient issue within the system (e.g. an inaccessible location) and the system is expected to recover automatically. Check the
locations_detailsfield for more details. 5- DELETE_FAILED =
An attempt to delete the association has failed. This is a terminal state and the association is not expected to be usable as some of its resources have been deleted. The only permitted operation is to retry deleting the association.
6