Class: Google::Cloud::NetworkSecurity::V1::ListFirewallEndpointAssociationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListFirewallEndpointAssociationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb
Overview
Message for response to listing Associations
Instance Attribute Summary collapse
-
#firewall_endpoint_associations ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::FirewallEndpointAssociation>
The list of Association.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#firewall_endpoint_associations ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::FirewallEndpointAssociation>
Returns The list of Association.
366 367 368 369 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 366 class ListFirewallEndpointAssociationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
366 367 368 369 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 366 class ListFirewallEndpointAssociationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
366 367 368 369 |
# File 'proto_docs/google/cloud/networksecurity/v1/firewall_activation.rb', line 366 class ListFirewallEndpointAssociationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |