Class: Google::Cloud::NetworkSecurity::V1::ListInterceptEndpointGroupsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListInterceptEndpointGroupsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/intercept.rb
Overview
Response message for ListInterceptEndpointGroups.
Instance Attribute Summary collapse
-
#intercept_endpoint_groups ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroup>
The endpoint groups from the specified parent.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#intercept_endpoint_groups ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::InterceptEndpointGroup>
Returns The endpoint groups from the specified parent.
194 195 196 197 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 194 class ListInterceptEndpointGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
194 195 196 197 |
# File 'proto_docs/google/cloud/networksecurity/v1/intercept.rb', line 194 class ListInterceptEndpointGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |