Class: Google::Cloud::NetworkSecurity::V1::ListServerTlsPoliciesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListServerTlsPoliciesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb
Overview
Request used by the ListServerTlsPolicies method.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Maximum number of ServerTlsPolicies to return per call.
-
#page_token ⇒ ::String
The value returned by the last
ListServerTlsPoliciesResponseIndicates that this is a continuation of a priorListServerTlsPoliciescall, and that the system should return the next page of data. -
#parent ⇒ ::String
Required.
-
#return_partial_success ⇒ ::Boolean
Optional.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Maximum number of ServerTlsPolicies to return per call.
169 170 171 172 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 169 class ListServerTlsPoliciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns The value returned by the last ListServerTlsPoliciesResponse
Indicates that this is a continuation of a prior
ListServerTlsPolicies call, and that the system
should return the next page of data.
169 170 171 172 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 169 class ListServerTlsPoliciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location from which the ServerTlsPolicies should
be listed, specified in the format projects/*/locations/{location}.
169 170 171 172 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 169 class ListServerTlsPoliciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#return_partial_success ⇒ ::Boolean
Returns Optional. Setting this field to true will opt the request into returning
the resources that are reachable, and into including the names of those
that were unreachable in the [ListServerTlsPoliciesResponse.unreachable]
field. This can only be true when reading across collections e.g. when
parent is set to "projects/example/locations/-".
169 170 171 172 |
# File 'proto_docs/google/cloud/networksecurity/v1/server_tls_policy.rb', line 169 class ListServerTlsPoliciesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |