Class: Google::Cloud::NetworkSecurity::V1::ListTlsInspectionPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::ListTlsInspectionPoliciesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb
Overview
Response returned by the ListTlsInspectionPolicies method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
If there might be more results than those appearing in this response, then 'next_page_token' is included.
-
#tls_inspection_policies ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy>
List of TlsInspectionPolicies resources.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns If there might be more results than those appearing in this response, then 'next_page_token' is included. To get the next set of results, call this method again using the value of 'next_page_token' as 'page_token'.
190 191 192 193 |
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 190 class ListTlsInspectionPoliciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tls_inspection_policies ⇒ ::Array<::Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy>
Returns List of TlsInspectionPolicies resources.
190 191 192 193 |
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 190 class ListTlsInspectionPoliciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
190 191 192 193 |
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 190 class ListTlsInspectionPoliciesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |