Class: Google::Cloud::NetworkSecurity::V1::SACRealm
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::SACRealm
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/sse_realm.rb
Overview
Represents a Secure Access Connect (SAC) realm resource.
A Secure Access Connect realm establishes a connection between your Google Cloud project and an SSE service.
Defined Under Namespace
Modules: SecurityService, State Classes: LabelsEntry, PairingKey
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#pairing_key ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm::PairingKey
readonly
Output only.
-
#security_service ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm::SecurityService
Immutable.
-
#state ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the realm was created.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Optional list of labels applied to the resource.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |
#name ⇒ ::String
Returns Identifier. Resource name, in the form
projects/{project}/locations/global/sacRealms/{sacRealm}.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |
#pairing_key ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm::PairingKey (readonly)
Returns Output only. Key to be shared with SSE service provider during pairing.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |
#security_service ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm::SecurityService
Returns Immutable. SSE service provider associated with the realm.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |
#state ⇒ ::Google::Cloud::NetworkSecurity::V1::SACRealm::State (readonly)
Returns Output only. State of the realm.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the realm was last updated.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/cloud/networksecurity/v1/sse_realm.rb', line 50 class SACRealm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Key to be shared with SSE service provider to establish global handshake. # @!attribute [r] key # @return [::String] # Output only. Key value. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. Timestamp in UTC of when this resource is considered # expired. It expires 7 days after creation. class PairingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SSE service provider module SecurityService # The default value. This value is used if the state is omitted. SECURITY_SERVICE_UNSPECIFIED = 0 # [Palo Alto Networks Prisma # Access](https://www.paloaltonetworks.com/sase/access). PALO_ALTO_PRISMA_ACCESS = 1 end # State of the realm. module State # No state specified. This should not be used. STATE_UNSPECIFIED = 0 # Has never been attached to a partner. # Used only for Prisma Access. PENDING_PARTNER_ATTACHMENT = 7 # Currently attached to a partner. PARTNER_ATTACHED = 1 # Was once attached to a partner but has been detached. PARTNER_DETACHED = 2 # Is not attached to a partner and has an expired pairing key. # Used only for Prisma Access. KEY_EXPIRED = 3 end end |