Class: Google::Cloud::NetworkSecurity::V1::SecurityProfile
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::SecurityProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb
Overview
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
Defined Under Namespace
Modules: ProfileType Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#custom_intercept_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::CustomInterceptProfile
The custom TPPI configuration for the SecurityProfile.
-
#custom_mirroring_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::CustomMirroringProfile
The custom Packet Mirroring v2 configuration for the SecurityProfile.
-
#description ⇒ ::String
Optional.
-
#etag ⇒ ::String
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Immutable.
-
#threat_prevention_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::ThreatPreventionProfile
The threat prevention configuration for the SecurityProfile.
-
#type ⇒ ::Google::Cloud::NetworkSecurity::V1::SecurityProfile::ProfileType
Immutable.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#url_filtering_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::UrlFilteringProfile
The URL filtering configuration for the SecurityProfile.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Resource creation timestamp.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#custom_intercept_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::CustomInterceptProfile
Returns The custom TPPI configuration for the SecurityProfile.
Note: The following fields are mutually exclusive: custom_intercept_profile, threat_prevention_profile, custom_mirroring_profile, url_filtering_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#custom_mirroring_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::CustomMirroringProfile
Returns The custom Packet Mirroring v2 configuration for the SecurityProfile.
Note: The following fields are mutually exclusive: custom_mirroring_profile, threat_prevention_profile, custom_intercept_profile, url_filtering_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#description ⇒ ::String
Returns Optional. An optional description of the profile. Max length 512 characters.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#etag ⇒ ::String (readonly)
Returns Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#name ⇒ ::String
Returns Immutable. Identifier. Name of the SecurityProfile resource. It matches
pattern
projects|organizations/*/locations/{location}/securityProfiles/{security_profile}.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#threat_prevention_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::ThreatPreventionProfile
Returns The threat prevention configuration for the SecurityProfile.
Note: The following fields are mutually exclusive: threat_prevention_profile, custom_mirroring_profile, custom_intercept_profile, url_filtering_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#type ⇒ ::Google::Cloud::NetworkSecurity::V1::SecurityProfile::ProfileType
Returns Immutable. The single ProfileType that the SecurityProfile resource configures.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last resource update timestamp.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |
#url_filtering_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::UrlFilteringProfile
Returns The URL filtering configuration for the SecurityProfile.
Note: The following fields are mutually exclusive: url_filtering_profile, threat_prevention_profile, custom_mirroring_profile, custom_intercept_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 132 class SecurityProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible types that the SecurityProfile resource can configure. module ProfileType # Profile type not specified. PROFILE_TYPE_UNSPECIFIED = 0 # Profile type for threat prevention. THREAT_PREVENTION = 1 # Profile type for packet mirroring v2 CUSTOM_MIRRORING = 2 # Profile type for TPPI. CUSTOM_INTERCEPT = 3 # Profile type for URL filtering. URL_FILTERING = 5 end end |