Class: Google::Cloud::NetworkSecurity::V1::SecurityProfileGroup
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::SecurityProfileGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb
Overview
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#custom_intercept_profile ⇒ ::String
Optional.
-
#custom_mirroring_profile ⇒ ::String
Optional.
-
#data_path_id ⇒ ::Integer
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#etag ⇒ ::String
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Immutable.
-
#threat_prevention_profile ⇒ ::String
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#url_filtering_profile ⇒ ::String
Optional.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Resource creation timestamp.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_intercept_profile ⇒ ::String
Returns Optional. Reference to a SecurityProfile with the CustomIntercept configuration.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_mirroring_profile ⇒ ::String
Returns Optional. Reference to a SecurityProfile with the CustomMirroring configuration.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#data_path_id ⇒ ::Integer (readonly)
Returns Output only. Identifier used by the data-path. Unique within {container,
location}.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. An optional description of the profile group. Max length 2048 characters.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String (readonly)
Returns Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Immutable. Identifier. Name of the SecurityProfileGroup resource. It
matches pattern
projects|organizations/*/locations/{location}/securityProfileGroups/{security_profile_group}.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#threat_prevention_profile ⇒ ::String
Returns Optional. Reference to a SecurityProfile with the ThreatPrevention configuration.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last resource update timestamp.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#url_filtering_profile ⇒ ::String
Returns Optional. Reference to a SecurityProfile with the UrlFiltering configuration.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group.rb', line 69 class SecurityProfileGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |