Module: Google::Cloud::NetworkSecurity::V1::ThreatAction
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/security_profile_group_threatprevention.rb
Overview
Threat action override.
Constant Summary collapse
- THREAT_ACTION_UNSPECIFIED =
Threat action not specified.
0- DEFAULT_ACTION =
The default action (as specified by the vendor) is taken.
4- ALLOW =
The packet matching this rule will be allowed to transmit.
1- ALERT =
The packet matching this rule will be allowed to transmit, but a threat_log entry will be sent to the consumer project.
2- DENY =
The packet matching this rule will be dropped, and a threat_log entry will be sent to the consumer project.
3