Class: Google::Cloud::NetworkSecurity::V1::UpdateSecurityProfileRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::UpdateSecurityProfileRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb
Overview
Request used by the UpdateSecurityProfile method.
Instance Attribute Summary collapse
-
#security_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::SecurityProfile
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Required.
Instance Attribute Details
#security_profile ⇒ ::Google::Cloud::NetworkSecurity::V1::SecurityProfile
Returns Required. Updated SecurityProfile resource.
190 191 192 193 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 190 class UpdateSecurityProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Required. Field mask is used to specify the fields to be overwritten in the SecurityProfile resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask.
190 191 192 193 |
# File 'proto_docs/google/cloud/networksecurity/v1/security_profile_group_service.rb', line 190 class UpdateSecurityProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |