Class: Google::Cloud::NetworkSecurity::V1::UpdateTlsInspectionPolicyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkSecurity::V1::UpdateTlsInspectionPolicyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb
Overview
Request used by the UpdateTlsInspectionPolicy method.
Instance Attribute Summary collapse
-
#tls_inspection_policy ⇒ ::Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#tls_inspection_policy ⇒ ::Google::Cloud::NetworkSecurity::V1::TlsInspectionPolicy
Returns Required. Updated TlsInspectionPolicy resource.
232 233 234 235 |
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 232 class UpdateTlsInspectionPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the TlsInspectionPolicy resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
232 233 234 235 |
# File 'proto_docs/google/cloud/networksecurity/v1/tls_inspection_policy.rb', line 232 class UpdateTlsInspectionPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |